@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * fn-database.c: Built-in database functions and functions registration
  *
@@ -808,45 +807,45 @@ gnumeric_getpivotdata (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 
 const GnmFuncDescriptor database_functions[] = {
 	{ "daverage", "rSr",
-	  help_daverage,   gnumeric_daverage, NULL, NULL, NULL,
+	  help_daverage,   gnumeric_daverage, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "dcount",   "rSr",
-	  help_dcount,     gnumeric_dcount, NULL, NULL, NULL,
+	  help_dcount,     gnumeric_dcount, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "dcounta",  "rSr",
-	  help_dcounta,    gnumeric_dcounta, NULL, NULL, NULL,
+	  help_dcounta,    gnumeric_dcounta, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "dget",     "rSr",
-	  help_dget,       gnumeric_dget, NULL, NULL, NULL,
+	  help_dget,       gnumeric_dget, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "dmax",     "rSr",
-	  help_dmax,       gnumeric_dmax, NULL, NULL, NULL,
+	  help_dmax,       gnumeric_dmax, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "dmin",     "rSr",
-	  help_dmin,       gnumeric_dmin, NULL, NULL, NULL,
+	  help_dmin,       gnumeric_dmin, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "dproduct", "rSr",
-	  help_dproduct,   gnumeric_dproduct, NULL, NULL, NULL,
+	  help_dproduct,   gnumeric_dproduct, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "dstdev",   "rSr",
-	  help_dstdev,     gnumeric_dstdev, NULL, NULL, NULL,
+	  help_dstdev,     gnumeric_dstdev, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "dstdevp",  "rSr",
-	  help_dstdevp,    gnumeric_dstdevp, NULL, NULL, NULL,
+	  help_dstdevp,    gnumeric_dstdevp, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "dsum",     "rSr",
-	  help_dsum,       gnumeric_dsum, NULL, NULL, NULL,
+	  help_dsum,       gnumeric_dsum, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "dvar",     "rSr",
-	  help_dvar,       gnumeric_dvar, NULL, NULL, NULL,
+	  help_dvar,       gnumeric_dvar, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "dvarp",    "rSr",
-	  help_dvarp,      gnumeric_dvarp, NULL, NULL, NULL,
+	  help_dvarp,      gnumeric_dvarp, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 
 /* XL stores in lookup */
 	{ "getpivotdata", "rs",
-	  help_getpivotdata, gnumeric_getpivotdata, NULL, NULL, NULL,
+	  help_getpivotdata, gnumeric_getpivotdata, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_SUBSET, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 
         {NULL}
