@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * fn-date.c:  Built in date functions.
  *
@@ -1417,112 +1416,112 @@ gnumeric_days (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 
 GnmFuncDescriptor const datetime_functions[] = {
 	{ "date",        "fff",   help_date,
-	  gnumeric_date, NULL, NULL, NULL,
+	  gnumeric_date, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_DATE,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "datevalue",   "f",     help_datevalue,
-	  gnumeric_datevalue, NULL, NULL, NULL,
+	  gnumeric_datevalue, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "datedif",     "ffs",   help_datedif,
-	  gnumeric_datedif, NULL, NULL, NULL,
+	  gnumeric_datedif, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "day",         "f",     help_day,
-	  gnumeric_day, NULL, NULL, NULL,
+	  gnumeric_day, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "days360",     "ff|f",  help_days360,
-	  gnumeric_days360, NULL, NULL, NULL,
+	  gnumeric_days360, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "edate",       "ff",    help_edate,
-	  gnumeric_edate, NULL, NULL, NULL,
+	  gnumeric_edate, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_DATE,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "eomonth",     "f|f",   help_eomonth,
-	  gnumeric_eomonth, NULL, NULL, NULL,
+	  gnumeric_eomonth, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_DATE,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "hour",        "f",     help_hour,
-	  gnumeric_hour, NULL, NULL, NULL,
+	  gnumeric_hour, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "minute",      "f",     help_minute,
-	  gnumeric_minute, NULL, NULL, NULL,
+	  gnumeric_minute, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "month",       "f",     help_month,
-	  gnumeric_month, NULL, NULL, NULL,
+	  gnumeric_month, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "networkdays", "ff|?A",
-	  help_networkdays, gnumeric_networkdays, NULL, NULL, NULL,
+	  help_networkdays, gnumeric_networkdays, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "now",         "", help_now,
-	  gnumeric_now, NULL, NULL, NULL,
+	  gnumeric_now, NULL,
 	  GNM_FUNC_VOLATILE + GNM_FUNC_AUTO_TIME,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "odf.time",        "fff",   help_odf_time,
-	  gnumeric_odf_time, NULL, NULL, NULL,
+	  gnumeric_odf_time, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_TIME,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "second",      "f",     help_second,
-	  gnumeric_second, NULL, NULL, NULL,
+	  gnumeric_second, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "time",        "fff",   help_time,
-	  gnumeric_time, NULL, NULL, NULL,
+	  gnumeric_time, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_TIME,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "timevalue",   "f",     help_timevalue,
-	  gnumeric_timevalue, NULL, NULL, NULL,
+	  gnumeric_timevalue, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "today",       "", help_today,
-	  gnumeric_today, NULL, NULL, NULL,
+	  gnumeric_today, NULL,
 	  GNM_FUNC_VOLATILE + GNM_FUNC_AUTO_DATE,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "weekday",     "f|f",   help_weekday,
-	  gnumeric_weekday, NULL, NULL, NULL,
+	  gnumeric_weekday, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "weeknum",     "f|f",   help_weeknum,
-	  gnumeric_weeknum, NULL, NULL, NULL,
+	  gnumeric_weeknum, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "workday",     "ff|?A",  help_workday,
-	  gnumeric_workday, NULL, NULL, NULL,
+	  gnumeric_workday, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_DATE,
 	  GNM_FUNC_IMPL_STATUS_SUBSET, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "year",        "f",     help_year,
-	  gnumeric_year, NULL, NULL, NULL,
+	  gnumeric_year, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "yearfrac",	"ff|f",     help_yearfrac,
-	  gnumeric_yearfrac, NULL, NULL, NULL,
+	  gnumeric_yearfrac, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 
 	{ "unix2date",   "f",     help_unix2date,
-	  gnumeric_unix2date, NULL, NULL, NULL,
+	  gnumeric_unix2date, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_DATE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "date2unix",   "f",     help_date2unix,
-	  gnumeric_date2unix, NULL, NULL, NULL,
+	  gnumeric_date2unix, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "isoweeknum",  "f",     help_isoweeknum,
-	  gnumeric_isoweeknum, NULL, NULL, NULL,
+	  gnumeric_isoweeknum, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "isoyear",     "f",     help_isoyear,
-	  gnumeric_isoyear, NULL, NULL, NULL,
+	  gnumeric_isoyear, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "days", "ff",
-	  help_days, gnumeric_days, NULL, NULL, NULL,
+	  help_days, gnumeric_days, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         {NULL}
