@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * fn-random.c:  Built in random number generation functions and functions
  *               registration
@@ -972,139 +971,139 @@ gnumeric_randstdist (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 
 GnmFuncDescriptor const random_functions[] = {
 	{ "rand",    "", help_rand,
-	  gnumeric_rand, NULL, NULL, NULL,
+	  gnumeric_rand, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randbernoulli", "f",    help_randbernoulli,
-	  gnumeric_randbernoulli, NULL, NULL, NULL,
+	  gnumeric_randbernoulli, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randbeta", "ff",    help_randbeta,
-	  gnumeric_randbeta, NULL, NULL, NULL,
+	  gnumeric_randbeta, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randbetween", "ff",  help_randbetween,
-	  gnumeric_randbetween, NULL, NULL, NULL,
+	  gnumeric_randbetween, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randbinom", "ff",  help_randbinom,
-	  gnumeric_randbinom, NULL, NULL, NULL,
+	  gnumeric_randbinom, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randcauchy", "f",    help_randcauchy,
-	  gnumeric_randcauchy, NULL, NULL, NULL,
+	  gnumeric_randcauchy, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randchisq", "f",    help_randchisq,
-	  gnumeric_randchisq, NULL, NULL, NULL,
+	  gnumeric_randchisq, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "randdiscrete", "r|r",
-	  help_randdiscrete, gnumeric_randdiscrete, NULL, NULL, NULL,
+	  help_randdiscrete, gnumeric_randdiscrete, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "randexp", "f",          help_randexp,
-	  gnumeric_randexp, NULL, NULL, NULL,
+	  gnumeric_randexp, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randexppow", "ff",          help_randexppow,
-	  gnumeric_randexppow, NULL, NULL, NULL,
+	  gnumeric_randexppow, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "randfdist", "ff",       help_randfdist,
-	  gnumeric_randfdist, NULL, NULL, NULL,
+	  gnumeric_randfdist, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randgamma", "ff",     help_randgamma,
-	  gnumeric_randgamma, NULL, NULL, NULL,
+	  gnumeric_randgamma, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randnormtail", "ff",     help_randnormtail,
-	  gnumeric_randnormtail, NULL, NULL, NULL,
+	  gnumeric_randnormtail, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "randgeom", "f",     help_randgeom,
-	  gnumeric_randgeom, NULL, NULL, NULL,
+	  gnumeric_randgeom, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randgumbel", "ff|f",     help_randgumbel,
-	  gnumeric_randgumbel, NULL, NULL, NULL,
+	  gnumeric_randgumbel, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "randhyperg", "fff",     help_randhyperg,
-	  gnumeric_randhyperg, NULL, NULL, NULL,
+	  gnumeric_randhyperg, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randlandau", "", help_randlandau,
-	  gnumeric_randlandau, NULL, NULL, NULL,
+	  gnumeric_randlandau, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "randlaplace", "f",  help_randlaplace,
-	  gnumeric_randlaplace, NULL, NULL, NULL,
+	  gnumeric_randlaplace, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "randlevy", "ff|f",  help_randlevy,
-	  gnumeric_randlevy, NULL, NULL, NULL,
+	  gnumeric_randlevy, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "randlog", "f",  help_randlog,
-	  gnumeric_randlog, NULL, NULL, NULL,
+	  gnumeric_randlog, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randlogistic", "f",  help_randlogistic,
-	  gnumeric_randlogistic, NULL, NULL, NULL,
+	  gnumeric_randlogistic, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "randlognorm", "ff",  help_randlognorm,
-	  gnumeric_randlognorm, NULL, NULL, NULL,
+	  gnumeric_randlognorm, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randnegbinom", "ff",  help_randnegbinom,
-	  gnumeric_randnegbinom, NULL, NULL, NULL,
+	  gnumeric_randnegbinom, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randnorm", "ff",  help_randnorm,
-	  gnumeric_randnorm, NULL, NULL, NULL,
+	  gnumeric_randnorm, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randpareto", "ff",  help_randpareto,
-	  gnumeric_randpareto, NULL, NULL, NULL,
+	  gnumeric_randpareto, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "randpoisson", "f",  help_randpoisson,
-	  gnumeric_randpoisson, NULL, NULL, NULL,
+	  gnumeric_randpoisson, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randrayleigh", "f",  help_randrayleigh,
-	  gnumeric_randrayleigh, NULL, NULL, NULL,
+	  gnumeric_randrayleigh, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randrayleightail", "ff",  help_randrayleightail,
-	  gnumeric_randrayleightail, NULL, NULL, NULL,
+	  gnumeric_randrayleightail, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "randsnorm", "|fff",  help_randsnorm,
-	  gnumeric_randsnorm, NULL, NULL, NULL,
+	  gnumeric_randsnorm, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randstdist", "ff",  help_randstdist,
-	  gnumeric_randstdist, NULL, NULL, NULL,
+	  gnumeric_randstdist, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
         { "randtdist", "f",  help_randtdist,
-	  gnumeric_randtdist, NULL, NULL, NULL,
+	  gnumeric_randtdist, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randuniform", "ff",  help_randuniform,
-	  gnumeric_randuniform, NULL, NULL, NULL,
+	  gnumeric_randuniform, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
         { "randweibull", "ff",  help_randweibull,
-	  gnumeric_randweibull, NULL, NULL, NULL,
+	  gnumeric_randweibull, NULL,
 	  GNM_FUNC_SIMPLE | GNM_FUNC_VOLATILE,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "simtable", NULL,  help_simtable,
-	  NULL,	gnumeric_simtable, NULL, NULL,
+	  NULL,	gnumeric_simtable,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 
         {NULL}
