@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * latex.c
  *
@@ -58,6 +57,7 @@
 #include <rendered-value.h>
 #include <cellspan.h>
 #include <print-info.h>
+#include <gutils.h>
 
 #include <locale.h>
 #include <gsf/gsf-output.h>
@@ -1287,7 +1287,7 @@ file_saver_sheet_get_extent (Sheet *sheet)
  * to render the format and contents of the cell.
  */
 void
-latex_file_save (G_GNUC_UNUSED GOFileSaver const *fs, G_GNUC_UNUSED GOIOContext *io_context,
+latex_file_save (GOFileSaver const *fs, G_GNUC_UNUSED GOIOContext *io_context,
 		 WorkbookView const *wb_view, GsfOutput *output)
 {
 	GnmCell *cell;
@@ -1300,8 +1300,8 @@ latex_file_save (G_GNUC_UNUSED GOFileSaver const *fs, G_GNUC_UNUSED GOIOContext
 	GnmStyleBorderType *prev_vert = NULL, *next_vert = NULL, *this_vert;
 	gboolean needs_hline;
 
-	/* Get the topmost sheet and its range from the plugin function argument. */
-	current_sheet = wb_view_cur_sheet(wb_view);
+	/* Get the sheet and its range from the plugin function argument. */
+	current_sheet = gnm_file_saver_get_sheet (fs, wb_view);
 	total_range = file_saver_sheet_get_extent (current_sheet);
 
 	/* This is the preamble of the LaTeX2e file. */
@@ -1551,7 +1551,7 @@ latex2e_table_write_file_header(GsfOutput *output)
 }
 
 /**
- * latex_table_file_save :  The LaTeX2e exporter plugin function.
+ * latex_table_file_save_impl :  The LaTeX2e exporter plugin function.
  *
  * @WorkbookView:     this provides the way to access the sheet being exported.
  * @outpu:            where we'll write.
@@ -1561,7 +1561,8 @@ latex2e_table_write_file_header(GsfOutput *output)
  * We try to avoid all formatting.
  */
 static void
-latex_table_file_save_impl (WorkbookView const *wb_view, GsfOutput *output, gboolean all)
+latex_table_file_save_impl (GOFileSaver const *fs, WorkbookView const *wb_view,
+			    GsfOutput *output, gboolean all)
 {
 	GnmCell *cell;
 	Sheet *current_sheet;
@@ -1571,8 +1572,8 @@ latex_table_file_save_impl (WorkbookView const *wb_view, GsfOutput *output, gboo
 	/* This is the preamble of the LaTeX2e file. */
 	latex2e_table_write_file_header(output);
 
-	/* Get the topmost sheet and its range from the plugin function argument. */
-	current_sheet = wb_view_cur_sheet(wb_view);
+	/* Get the sheet and its range from the plugin function argument. */
+	current_sheet = gnm_file_saver_get_sheet (fs, wb_view);
 	total_range = file_saver_sheet_get_extent (current_sheet);
 
 	/* Step through the sheet, writing cells as appropriate. */
@@ -1609,15 +1610,15 @@ latex_table_file_save_impl (WorkbookView const *wb_view, GsfOutput *output, gboo
  * @WorkbookView:     this provides the way to access the sheet being exported.
  * @output:           where we'll write.
  *
- * This writes the top sheet of a Gnumeric workbook as the content of a latex table environment.
- * We try to avoid all formatting.
+ * This writes the selected sheet of a Gnumeric workbook as the content of a
+ * latex table environment.  We try to avoid all formatting.
  */
 void
-latex_table_file_save (G_GNUC_UNUSED GOFileSaver const *fs,
+latex_table_file_save (GOFileSaver const *fs,
 		       G_GNUC_UNUSED GOIOContext *io_context,
 		       WorkbookView const *wb_view, GsfOutput *output)
 {
-	latex_table_file_save_impl (wb_view, output, TRUE);
+	latex_table_file_save_impl (fs, wb_view, output, TRUE);
 }
 
 /**
@@ -1628,13 +1629,13 @@ latex_table_file_save (G_GNUC_UNUSED GOFileSaver const *fs,
  * @WorkbookView:     this provides the way to access the sheet being exported.
  * @output:           where we'll write.
  *
- * This writes the top sheet of a Gnumeric workbook as the content of a latex table environment.
- * We try to avoid all formatting.
+ * This writes the selected sheet of a Gnumeric workbook as the content of a
+ * latex table environment.  We try to avoid all formatting.
  */
 void
-latex_table_visible_file_save (G_GNUC_UNUSED GOFileSaver const *fs,
-		       G_GNUC_UNUSED GOIOContext *io_context,
-		       WorkbookView const *wb_view, GsfOutput *output)
+latex_table_visible_file_save (GOFileSaver const *fs,
+			       G_GNUC_UNUSED GOIOContext *io_context,
+			       WorkbookView const *wb_view, GsfOutput *output)
 {
-	latex_table_file_save_impl (wb_view, output, FALSE);
+	latex_table_file_save_impl (fs, wb_view, output, FALSE);
 }
