@@ -15,21 +15,20 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "workbook-view.h"
-#include "workbook.h"
-#include "sheet.h"
-#include "style.h"
+#include <workbook-view.h>
+#include <workbook.h>
+#include <sheet.h>
+#include <style.h>
 #include "roff.h"
 #include "font.h"
-#include "cell.h"
-#include "cellspan.h"
+#include <cell.h>
+#include <cellspan.h>
 #include <goffice/goffice.h>
 
 #include <string.h>
