@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * py-gnumeric.c - "Gnumeric" module for Python
  *
@@ -7,18 +6,18 @@
 
 #include <gnumeric-config.h>
 #include <gnumeric.h>
-#include "application.h"
-#include "workbook.h"
-#include "cell.h"
-#include "mstyle.h"
-#include "sheet.h"
-#include "sheet-style.h"
-#include "position.h"
-#include "value.h"
-#include "expr.h"
-#include "func.h"
-#include "wbc-gtk.h"
-#include "parse-util.h"
+#include <application.h>
+#include <workbook.h>
+#include <cell.h>
+#include <mstyle.h>
+#include <sheet.h>
+#include <sheet-style.h>
+#include <position.h>
+#include <value.h>
+#include <expr.h>
+#include <func.h>
+#include <wbc-gtk.h>
+#include <parse-util.h>
 #include "gnm-py-interpreter.h"
 #include "py-gnumeric.h"
 
@@ -1751,6 +1750,13 @@ py_Workbook_gui_add (py_Workbook_object *self, PyObject *args)
 	return result;
 }
 
+static PyObject *
+py_Workbook_recalc (py_Workbook_object *self, PyObject *args)
+{
+       workbook_recalc(self->wb);
+       Py_RETURN_NONE;
+}
+
 static PyObject *
 py_Workbook_object_getattr (py_Workbook_object *self, gchar *name)
 {
@@ -1761,6 +1767,8 @@ py_Workbook_object_getattr (py_Workbook_object *self, gchar *name)
 		 METH_VARARGS},
 		{ (char *) "gui_add",	(PyCFunction) py_Workbook_gui_add,
 		 METH_VARARGS},
+		{ (char *) "recalc",    (PyCFunction) py_Workbook_recalc,
+		 METH_VARARGS},
 		{NULL, NULL}
 	};
 	return Py_FindMethod (methods, (PyObject *) self, name);
@@ -1939,7 +1947,7 @@ py_GnumericFunc_object_dealloc (py_GnumericFunc_object *self)
 {
 	g_return_if_fail (self != NULL);
 
-	gnm_func_unref (self->fn_def);
+	gnm_func_dec_usage (self->fn_def);
 	g_free (self->eval_pos);
 	PyObject_Del (self);
 }
@@ -1954,7 +1962,7 @@ py_new_GnumericFunc_object (GnmFunc *fn_def, const GnmEvalPos *opt_eval_pos)
 		return NULL;
 	}
 
-	gnm_func_ref (fn_def);
+	gnm_func_inc_usage (fn_def);
 	self->fn_def = fn_def;
 	if (opt_eval_pos != NULL) {
 		self->eval_pos = g_new (GnmEvalPos, 1);
