@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * cellspan.c: Keep track of the columns on which a cell
@@ -17,17 +16,17 @@
  * the "owner" of the cell to be able to repaint its contents.
  */
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "cellspan.h"
+#include <gnumeric.h>
+#include <cellspan.h>
 
-#include "cell.h"
-#include "sheet.h"
-#include "sheet-merge.h"
-#include "sheet-style.h"
-#include "style.h"
-#include "colrow.h"
-#include "value.h"
-#include "rendered-value.h"
+#include <cell.h>
+#include <sheet.h>
+#include <sheet-merge.h>
+#include <sheet-style.h>
+#include <style.h>
+#include <colrow.h>
+#include <value.h>
+#include <rendered-value.h>
 
 static guint
 col_hash (gconstpointer key)
@@ -189,7 +188,7 @@ cell_span_info_get_type (void)
  *
  * We could probably have done the same thing with the span regions too, but
  * the current representation is not well suited to that type of search
- * returns TRUE if the cell is empty.
+ * returns %TRUE if the cell is empty.
  */
 static inline gboolean
 cellspan_is_empty (int col, GnmCell const *ok_span_cell)
