@@ -1,4 +1,3 @@
-/* vim: set sw=8:  -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * colrow.c: Utilities for Rows and Columns
  *
@@ -20,20 +19,20 @@
  * USA
  */
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "colrow.h"
+#include <gnumeric.h>
+#include <colrow.h>
 
-#include "sheet.h"
-#include "sheet-view.h"
-#include "sheet-private.h"
-#include "application.h"
-#include "parse-util.h"
-#include "selection.h"
-#include "ranges.h"
-#include "sheet-merge.h"
-#include "cell.h"
-#include "cellspan.h"
-#include "rendered-value.h"
+#include <sheet.h>
+#include <sheet-view.h>
+#include <sheet-private.h>
+#include <application.h>
+#include <parse-util.h>
+#include <selection.h>
+#include <ranges.h>
+#include <sheet-merge.h>
+#include <cell.h>
+#include <cellspan.h>
+#include <rendered-value.h>
 #include <goffice/goffice.h>
 #include <string.h>
 
