@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * about.c: Shows the contributors to Gnumeric.
  *
@@ -22,7 +21,7 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
+#include <dialogs/dialogs.h>
 #include <string.h>
 
 #include <gui-util.h>
@@ -30,7 +29,6 @@
 #include <wbc-gtk.h>
 #include <gnm-format.h>
 #include <goffice/goffice.h>
-#include <gtk/gtk.h>
 
 #define ABOUT_KEY          "about-dialog"
 
@@ -54,6 +52,8 @@ typedef enum {
 	GNM_ART			= 1 << 10,
 	GNM_PACKAGING		= 1 << 11
 } ContribTypes;
+
+#if 0
 #define GNM_ABOUT_NUM_TYPES	       12
 static char const * const about_types[GNM_ABOUT_NUM_TYPES] = {
 	N_("Core"),
@@ -69,6 +69,7 @@ static char const * const about_types[GNM_ABOUT_NUM_TYPES] = {
 	N_("Art"),
 	N_("Packaging")
 };
+#endif
 
 static struct {
 	char const *name;
@@ -523,7 +524,7 @@ create_animation (AboutState *state)
 
 	OVERLAP (2000);
 
-	r = make_text_item (state, _("https://bugzilla.gnome.org/"), 3000);
+	r = make_text_item (state, PACKAGE_BUGREPORT, 3000);
 	set_text_motion (r, 0.5, 0.9, 0.5, 0.1);
 	APPENDR (r);
 
