@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-advanced-filter.c:
  *
@@ -20,35 +19,33 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  **/
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <sheet.h>
 #include <cell.h>
 #include <ranges.h>
 #include <gui-util.h>
-#include <tool-dialogs.h>
-#include <dao-gui-utils.h>
+#include <dialogs/tool-dialogs.h>
+#include <dialogs/dao-gui-utils.h>
 #include <value.h>
 #include <wbc-gtk.h>
 
-#include <gtk/gtk.h>
-#include <widgets/gnumeric-expr-entry.h>
+#include <widgets/gnm-expr-entry.h>
 #include <widgets/gnm-dao.h>
-#include "filter.h"
-#include "analysis-tools.h"
-#include "commands.h"
+#include <tools/filter.h>
+#include <tools/analysis-tools.h>
+#include <commands.h>
 
 
 #define ADVANCED_FILTER_KEY         "advanced-filter-dialog"
 
-typedef GenericToolState AdvancedFilterState;
+typedef GnmGenericToolState AdvancedFilterState;
 
 /**
  * advanced_filter_update_sensitivity_cb:
@@ -123,7 +120,7 @@ advanced_filter_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	criteria = gnm_expr_entry_parse_as_value
 		(state->input_entry_2, state->sheet);
 
-        dao  = parse_output ((GenericToolState *) state, NULL);
+        dao  = parse_output ((GnmGenericToolState *) state, NULL);
 
 	w = go_gtk_builder_get_widget (state->gui, "unique-button");
 	unique = (1 == gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)));
@@ -159,7 +156,7 @@ advanced_filter_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 		gtk_widget_destroy (state->dialog);
 		break;
 	case analysis_tools_invalid_field:
-		error_in_entry ((GenericToolState *) state,
+		error_in_entry ((GnmGenericToolState *) state,
 				GTK_WIDGET (state->input_entry_2),
 				_("The given criteria are invalid."));
 		break;
@@ -172,7 +169,7 @@ advanced_filter_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	default:
 		text = g_strdup_printf (_("An unexpected error has occurred: "
 					  "%d."), err);
-		error_in_entry ((GenericToolState *) state,
+		error_in_entry ((GnmGenericToolState *) state,
 				GTK_WIDGET (state->input_entry), text);
 		g_free (text);
 		break;
@@ -183,10 +180,8 @@ advanced_filter_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 /**
  * dialog_advanced_filter:
  * @wbcg:
- * @sheet:
  *
  * Show the dialog (guru).
- *
  **/
 void
 dialog_advanced_filter (WBCGtk *wbcg)
@@ -206,7 +201,7 @@ dialog_advanced_filter (WBCGtk *wbcg)
 
 	if (dialog_tool_init (state, wbcg, wb_control_cur_sheet (wbc),
 			      GNUMERIC_HELP_LINK_ADVANCED_FILTER,
-			      "advanced-filter.ui", "Filter",
+			      "res:ui/advanced-filter.ui", "Filter",
 			      _("Could not create the Advanced Filter dialog."),
 			      ADVANCED_FILTER_KEY,
 			      G_CALLBACK (advanced_filter_ok_clicked_cb), NULL,
@@ -217,7 +212,7 @@ dialog_advanced_filter (WBCGtk *wbcg)
 	gnm_dao_set_inplace (GNM_DAO (state->gdao), _("Filter _in-place"));
 	gnm_dao_set_put (GNM_DAO (state->gdao), FALSE, FALSE);
 	advanced_filter_update_sensitivity_cb (NULL, state);
-	tool_load_selection ((GenericToolState *)state, TRUE);
+	tool_load_selection ((GnmGenericToolState *)state, TRUE);
 
         return;
 }
