@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-function-wizard.c:  The formula guru
  *
@@ -26,8 +25,8 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <parse-util.h>
 #include <gui-util.h>
@@ -43,10 +42,9 @@
 #include <func.h>
 #include <gnm-format.h>
 #include <goffice/goffice.h>
-#include <widgets/gnumeric-expr-entry.h>
-#include <widgets/gnumeric-cell-renderer-expr-entry.h>
+#include <widgets/gnm-expr-entry.h>
+#include <widgets/gnm-cell-renderer-expr-entry.h>
 
-#include <gtk/gtk.h>
 #include <locale.h>
 #include <string.h>
 
@@ -85,7 +83,7 @@ typedef struct
 	gint old_height_request;
 	gint old_width_request;
 
-	GnumericCellRendererExprEntry *cellrenderer;
+	GnmCellRendererExprEntry *cellrenderer;
 	GtkTreeViewColumn *column;
 	GtkCellEditable *editable;
 } FormulaGuruState;
@@ -271,7 +269,7 @@ dialog_formula_guru_update_this_child (GtkTreeIter *child, FormulaGuruState *sta
 
 
 static void
-dialog_formula_guru_adjust_children (GtkTreeIter *parent, GnmFunc const *fd,
+dialog_formula_guru_adjust_children (GtkTreeIter *parent, GnmFunc *fd,
 				     FormulaGuruState *state)
 {
 	gboolean is_non_fun;
@@ -279,7 +277,6 @@ dialog_formula_guru_adjust_children (GtkTreeIter *parent, GnmFunc const *fd,
 	gint min_arg, max_arg, args = 0, i;
 	char *arg_name;
 
-
 	if (fd == NULL) {
 		gtk_tree_model_get (GTK_TREE_MODEL(state->model), parent,
 				    IS_NON_FUN, &is_non_fun,
@@ -670,7 +667,7 @@ cb_dialog_formula_guru_ok_clicked (G_GNUC_UNUSED GtkWidget *button,
 				   FormulaGuruState *state)
 {
 	if (state->cellrenderer->entry)
-		gnumeric_cell_renderer_expr_entry_editing_done (
+		gnm_cell_renderer_expr_entry_editing_done (
 			GTK_CELL_EDITABLE (state->cellrenderer->entry),
 			state->cellrenderer);
 	wbcg_edit_finish (state->wbcg,
@@ -892,14 +889,14 @@ dialog_formula_guru_init (FormulaGuruState *state)
 		G_CALLBACK (cb_dialog_formula_guru_selection_changed), state);
 
 	column = gtk_tree_view_column_new_with_attributes (_("Name"),
-							   gnumeric_cell_renderer_text_new (),
+							   gnm_cell_renderer_text_new (),
 							   "text", ARG_NAME, NULL);
 	gtk_tree_view_append_column (state->treeview, column);
 	column = gtk_tree_view_column_new_with_attributes (_("Type"),
-							   gnumeric_cell_renderer_text_new (),
+							   gnm_cell_renderer_text_new (),
 							   "text", ARG_TYPE, NULL);
 	gtk_tree_view_append_column (state->treeview, column);
-	renderer = gnumeric_cell_renderer_expr_entry_new (state->wbcg);
+	renderer = gnm_cell_renderer_expr_entry_new (state->wbcg);
 	state->cellrenderer = GNM_CELL_RENDERER_EXPR_ENTRY (renderer);
 	g_signal_connect (G_OBJECT (renderer), "edited",
 			  G_CALLBACK (cb_dialog_formula_guru_edited), state);
@@ -1034,7 +1031,7 @@ dialog_formula_guru (WBCGtk *wbcg, GnmFunc *fd)
 	}
 
 	/* Get the dialog and check for errors */
-	gui = gnm_gtk_builder_load ("formula-guru.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/formula-guru.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
 		return;
 
