@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * dialog-hyperlink.c: Add or edit a hyperlink
@@ -23,13 +22,13 @@
 
 #include <gnumeric-config.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <commands.h>
-#include <widgets/gnumeric-expr-entry.h>
-#include "expr-name.h"
-#include "expr.h"
+#include <widgets/gnm-expr-entry.h>
+#include <expr-name.h>
+#include <expr.h>
 #include <gui-util.h>
 #include <hlink.h>
 #include <mstyle.h>
@@ -41,7 +40,6 @@
 #include <wbc-gtk.h>
 #include <goffice/goffice.h>
 
-#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 
 #include <string.h>
@@ -61,6 +59,8 @@ typedef struct {
 	GnmExprEntry *internal_link_ee;
 	GnmHLink  *link;
 	gboolean   is_new;
+
+	GtkWidget *use_def_widget;
 } HyperlinkState;
 
 static void
@@ -104,14 +104,12 @@ dhl_set_tip (HyperlinkState* state)
 	if (tip != NULL) {
 		char const * const target = gnm_hlink_get_target (state->link);
 		char *default_tip = dhl_get_default_tip (target);
-
-		if (strcmp (tip, default_tip) == 0) {
-			w = go_gtk_builder_get_widget (state->gui, "use-default-tip");
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
-			g_free (default_tip);
+		gboolean is_default = (strcmp (tip, default_tip) == 0);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (state->use_def_widget),
+					      is_default);
+		g_free (default_tip);
+		if (is_default)
 			return;
-		} else
-			g_free (default_tip);
 	}
 	w = go_gtk_builder_get_widget (state->gui, "use-this-tip");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
@@ -125,10 +123,8 @@ dhl_set_tip (HyperlinkState* state)
 static char *
 dhl_get_tip (HyperlinkState *state, char const *target)
 {
-	GtkWidget *w = go_gtk_builder_get_widget (state->gui, "use-default-tip");
-
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)))
-		return dhl_get_default_tip (target);
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (state->use_def_widget)))
+		return NULL;
 	else {
 		char *tip;
 		GtkTextBuffer *tb = gtk_text_view_get_buffer
@@ -386,6 +382,7 @@ dhl_cb_ok (G_GNUC_UNUSED GtkWidget *button, HyperlinkState *state)
 	wb_control_sheet_focus (GNM_WBC (state->wbcg), state->sheet);
 
 	if (target) {
+		gnm_hlink_set_sheet (state->link, state->sheet);
 		gnm_hlink_set_target (state->link, target);
 		tip = dhl_get_tip (state, target);
 		gnm_hlink_set_tip (state->link, tip);
@@ -444,7 +441,7 @@ dhl_set_type (HyperlinkState *state, GType type)
 {
 	GnmHLink *old = state->link;
 
-	state->link = g_object_new (type, NULL);
+	state->link = gnm_hlink_new (type, state->sheet);
 	if (old != NULL) {
 		gnm_hlink_set_target (state->link, gnm_hlink_get_target (old));
 		gnm_hlink_set_tip (state->link, gnm_hlink_get_tip (old));
@@ -583,7 +580,7 @@ dialog_hyperlink (WBCGtk *wbcg, SheetControl *sc)
 	if (gnm_dialog_raise_if_exists (wbcg, DIALOG_KEY))
 		return;
 
-	gui = gnm_gtk_builder_load ("hyperlink.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/hyperlink.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return;
 
@@ -594,21 +591,25 @@ dialog_hyperlink (WBCGtk *wbcg, SheetControl *sc)
 	state->gui  = gui;
         state->dialog = go_gtk_builder_get_widget (state->gui, "hyperlink-dialog");
 
+	state->use_def_widget = go_gtk_builder_get_widget (state->gui, "use-default-tip");
+
 	state->sheet = sc_sheet (sc);
-	for (ptr = sc_view (sc)->selections; ptr != NULL; ptr = ptr->next)
-		if (NULL != (link = sheet_style_region_contains_link (state->sheet, ptr->data)))
+	for (ptr = sc_view (sc)->selections; ptr != NULL; ptr = ptr->next) {
+		GnmRange const *r = ptr->data;
+		link = sheet_style_region_contains_link (state->sheet, r);
+		if (link)
 			break;
+	}
 
 	/* We are creating a new link since the existing link */
 	/* may be used in many places. */
 	/* We are duplicating it here rather than in an ok handler in case */
-	/* The link is changed for a differnt cell in a different view. */
-	state->link = g_object_new (gnm_hlink_url_get_type (), NULL);
+	/* The link is changed for a differnet cell in a different view. */
 	if (link == NULL) {
-		state->link = g_object_new (gnm_hlink_url_get_type (), NULL);
+		state->link = gnm_hlink_new (gnm_hlink_url_get_type (), state->sheet);
 		state->is_new = TRUE;
 	} else {
-		state->link = g_object_new (G_OBJECT_TYPE (link), NULL);
+		state->link = gnm_hlink_new (G_OBJECT_TYPE (link), state->sheet);
 		state->is_new = FALSE;
 		gnm_hlink_set_target (state->link, gnm_hlink_get_target (link));
 		gnm_hlink_set_tip (state->link, gnm_hlink_get_tip (link));
