@@ -21,8 +21,8 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <gui-util.h>
 #include <selection.h>
@@ -35,7 +35,6 @@
 #include <wbc-gtk.h>
 #include <command-context.h>
 
-#include <gtk/gtk.h>
 
 #define INSERT_CELL_DIALOG_KEY "insert-cells-dialog"
 
@@ -138,7 +137,7 @@ dialog_insert_cells (WBCGtk *wbcg)
 	if (gnm_dialog_raise_if_exists (wbcg, INSERT_CELL_DIALOG_KEY))
 		return;
 
-	gui = gnm_gtk_builder_load ("insert-cells.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/insert-cells.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
 		return;
 
