@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * plugin-manager.c: Dialog used to load plugins into the Gnumeric
  * spreadsheet
@@ -27,8 +26,8 @@
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 #include <application.h>
 #include <wbc-gtk.h>
 #include <gnumeric-conf.h>
@@ -37,7 +36,6 @@
 
 #include <goffice/goffice.h>
 
-#include <gtk/gtk.h>
 #include <gsf/gsf-impl-utils.h>
 
 #include <string.h>
@@ -652,7 +650,7 @@ dialog_plugin_manager (WBCGtk *wbcg)
 	if (gnm_dialog_raise_if_exists (wbcg, PLUGIN_MANAGER_DIALOG_KEY))
 		return;
 
-	gui = gnm_gtk_builder_load ("plugin-manager.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/plugin-manager.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
 		return;
 
