@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * dialog-so-list.c: A property dialog for lists and combos
@@ -22,8 +21,8 @@
  */
 #include <gnumeric-config.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <expr.h>
 #include <selection.h>
@@ -36,8 +35,7 @@
 #include <gui-util.h>
 #include <parse-util.h>
 #include <commands.h>
-#include <widgets/gnumeric-expr-entry.h>
-#include <gtk/gtk.h>
+#include <widgets/gnm-expr-entry.h>
 #include <glib/gi18n.h>
 
 #define DIALOG_SO_LIST_KEY "so-list"
@@ -103,7 +101,7 @@ so_list_init (GnmDialogSOList *state, WBCGtk *wbcg, SheetObject *so)
 	GnmExprTop const *texpr;
 	GtkBuilder *gui;
 
-	gui = gnm_gtk_builder_load ("so-list.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/so-list.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
                 return TRUE;
 
