@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-solver.c:
  *
@@ -19,19 +18,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <gui-util.h>
 #include <func.h>
-#include <tool-dialogs.h>
+#include <dialogs/tool-dialogs.h>
 #include <value.h>
 #include <cell.h>
 #include <sheet.h>
@@ -46,12 +44,11 @@
 #include <selection.h>
 #include <application.h>
 #include <tools/gnm-solver.h>
-#include <widgets/gnumeric-expr-entry.h>
+#include <widgets/gnm-expr-entry.h>
 
-#include <gtk/gtk.h>
 #include <goffice/goffice.h>
 #include <string.h>
-#include <scenarios.h>
+#include <tools/scenarios.h>
 
 #define SOLVER_KEY            "solver-dialog"
 
@@ -154,7 +151,7 @@ dialog_set_sec_button_sensitivity (G_GNUC_UNUSED GtkWidget *dummy,
 	gtk_widget_set_sensitive (GTK_WIDGET (state->rhs.entry), has_rhs);
 	gtk_widget_set_sensitive (GTK_WIDGET (state->rhs.label), has_rhs);
 
-	/* Return TRUE iff the current constraint is valid.  */
+	/* Return %TRUE iff the current constraint is valid.  */
 	return ready;
 }
 
@@ -911,14 +908,14 @@ do {									\
 
 
 /**
- * dialog_init:
+ * dialog_solver_init:
  * @state:
  *
  * Create the dialog (guru).
  *
  **/
 static gboolean
-dialog_init (SolverState *state)
+dialog_solver_init (SolverState *state)
 {
 	GtkGrid *grid;
 	GnmSolverParameters *param;
@@ -932,7 +929,7 @@ dialog_init (SolverState *state)
 
 	param = state->sheet->solver_parameters;
 
-	state->gui = gnm_gtk_builder_load ("solver.ui", NULL, GO_CMD_CONTEXT (state->wbcg));
+	state->gui = gnm_gtk_builder_load ("res:ui/solver.ui", NULL, GO_CMD_CONTEXT (state->wbcg));
         if (state->gui == NULL)
                 return TRUE;
 
@@ -1262,7 +1259,7 @@ dialog_solver (WBCGtk *wbcg, Sheet *sheet)
 	state->orig_params = gnm_solver_param_dup (sheet->solver_parameters,
 						   sheet);
 
-	if (dialog_init (state)) {
+	if (dialog_solver_init (state)) {
 		go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
 				 _("Could not create the Solver dialog."));
 		unref_state (state);
