@@ -1,12 +1,11 @@
 #ifndef GNUMERIC_DIALOG_STF_H
 #define GNUMERIC_DIALOG_STF_H
 
-#include "dialog-stf-preview.h"
-#include "gui-util.h"
+#include <dialogs/dialog-stf-preview.h>
+#include <gui-util.h>
 #include <stf-parse.h>
 #include <goffice/goffice.h>
 
-#include <gtk/gtk.h>
 
 /* for the main_page */
 typedef struct {
