@@ -24,29 +24,28 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <gui-util.h>
-#include <widgets/gnumeric-expr-entry.h>
+#include <widgets/gnm-expr-entry.h>
 #include <tools/tabulate.h>
 #include <wbc-gtk.h>
-#include "ranges.h"
-#include "value.h"
-#include "sheet.h"
-#include "mstyle.h"
-#include "workbook.h"
-#include "mathfunc.h"
-#include "cell.h"
-#include "commands.h"
-#include "gnm-format.h"
-#include "number-match.h"
-#include "mstyle.h"
-#include "style-border.h"
-#include "sheet-style.h"
-#include "style-color.h"
+#include <ranges.h>
+#include <value.h>
+#include <sheet.h>
+#include <mstyle.h>
+#include <workbook.h>
+#include <mathfunc.h>
+#include <cell.h>
+#include <commands.h>
+#include <gnm-format.h>
+#include <number-match.h>
+#include <mstyle.h>
+#include <style-border.h>
+#include <sheet-style.h>
+#include <style-color.h>
 
-#include <gtk/gtk.h>
 #include <string.h>
 
 #define TABULATE_KEY "tabulate-dialog"
@@ -301,7 +300,7 @@ dialog_tabulate (WBCGtk *wbcg, Sheet *sheet)
 
 	if (gnm_dialog_raise_if_exists (wbcg, TABULATE_KEY))
 		return;
-	gui = gnm_gtk_builder_load ("tabulate.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/tabulate.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return;
 
