@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * expr-name.c: Supported named expressions
  *
@@ -12,17 +11,17 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
-#include "gnumeric.h"
-#include "expr-name.h"
+#include <gnumeric.h>
+#include <expr-name.h>
 
-#include "dependent.h"
-#include "value.h"
-#include "workbook-priv.h"
-#include "expr.h"
-#include "sheet.h"
-#include "ranges.h"
-#include "gutils.h"
-#include "sheet-style.h"
+#include <dependent.h>
+#include <value.h>
+#include <workbook-priv.h>
+#include <expr.h>
+#include <sheet.h>
+#include <ranges.h>
+#include <gutils.h>
+#include <sheet-style.h>
 
 #include <goffice/goffice.h>
 
@@ -683,11 +682,11 @@ expr_name_queue_deps (GnmNamedExpr *nexpr)
 }
 
 /**
- * expr_name_add:
+ * expr_name_add: (skip)
  * @pp:
  * @name:
  * @texpr: if texpr == NULL then create a placeholder with value #NAME?
- * @error_msg:
+ * @error_msg: (out) (optional) (nullable):
  * @link_to_container:
  *
  * Absorbs the reference to @texpr.
@@ -698,7 +697,7 @@ expr_name_queue_deps (GnmNamedExpr *nexpr)
  * 1) new names with @link_to_container TRUE are referenced by the container.
  *    The caller DOES NOT OWN a reference to the result, and needs to add their
  *    own.
- * 2) if @link_to_container is FALSE the caller DOES OWN a reference, and
+ * 2) if @link_to_container is %FALSE the caller DOES OWN a reference, and
  *    can free the result by unrefing the name.
  **/
 GnmNamedExpr *
@@ -716,6 +715,9 @@ expr_name_add (GnmParsePos const *pp, char const *name,
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (stub == NULL || stub->is_placeholder, NULL);
 
+	if (error_msg)
+		*error_msg = NULL;
+
 	fake_name.str = name;
 
 	if (gnm_debug_flag ("names")) {
@@ -768,9 +770,6 @@ expr_name_add (GnmParsePos const *pp, char const *name,
 		}
 	}
 
-	if (error_msg)
-		*error_msg = NULL;
-
 	if (nexpr == NULL) {
 		if (stub != NULL) {
 			nexpr = stub;
@@ -815,10 +814,8 @@ expr_name_unref (GnmNamedExpr *nexpr)
 
 	g_return_if_fail (nexpr->scope == NULL);
 
-	if (nexpr->name) {
-		go_string_unref (nexpr->name);
-		nexpr->name = NULL;
-	}
+	go_string_unref (nexpr->name);
+	nexpr->name = NULL;
 
 	if (nexpr->texpr != NULL)
 		expr_name_set_expr (nexpr, NULL);
@@ -1104,7 +1101,7 @@ expr_name_remove_dep (GnmNamedExpr *nexpr, GnmDependent *dep)
  * expr_name_is_placeholder:
  * @ne:
  *
- * Returns TRUE if @ne is a placeholder for an unknown name
+ * Returns: %TRUE if @ne is a placeholder for an unknown name
  **/
 gboolean
 expr_name_is_placeholder (GnmNamedExpr const *nexpr)
