@@ -1,9 +1,8 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_EXPR_NAME_H_
 # define _GNM_EXPR_NAME_H_
 
-#include "gnumeric.h"
-#include "position.h"
+#include <gnumeric.h>
+#include <position.h>
 #include <goffice/goffice.h>
 
 G_BEGIN_DECLS
@@ -34,10 +33,11 @@ void expr_name_perm_add        (Sheet *sheet,
 				char const *name,
 				GnmExprTop const *texpr,
 				gboolean is_editable);
-void	 expr_name_ref	      (GnmNamedExpr *nexpr);
+GnmNamedExpr *expr_name_ref   (GnmNamedExpr *nexpr);
 void	 expr_name_unref      (GnmNamedExpr *nexpr);
 void     expr_name_remove     (GnmNamedExpr *nexpr);
-GnmValue*expr_name_eval       (GnmNamedExpr const *ne, GnmEvalPos const *ep,
+GnmValue*expr_name_eval       (GnmNamedExpr const *nexpr,
+			       GnmEvalPos const *pos,
 			       GnmExprEvalFlags flags);
 
 const char *expr_name_name    (GnmNamedExpr const *nexpr);
@@ -65,17 +65,6 @@ GOUndo *expr_name_set_expr_undo_new (GnmNamedExpr *nexpr);
 
 /******************************************************************************/
 
-struct _GnmNamedExprCollection {
-	/* all the defined names */
-	GHashTable *names;
-
-	/* placeholders for references to undefined names */
-	GHashTable *placeholders;
-
-	/* <private> */
-	unsigned ref_count;     /* boxed type */
-};
-
 GType gnm_named_expr_collection_get_type (void);
 GnmNamedExprCollection *gnm_named_expr_collection_new (void);
 void gnm_named_expr_collection_free (GnmNamedExprCollection *names);
@@ -88,6 +77,11 @@ GSList  *gnm_named_expr_collection_list (GnmNamedExprCollection const *scope);
 
 GnmNamedExpr *gnm_named_expr_collection_lookup (GnmNamedExprCollection const *scope,
 						char const *name);
+void gnm_named_expr_collection_dump (GnmNamedExprCollection *names,
+				     const char *id);
+gboolean gnm_named_expr_collection_sanity_check (GnmNamedExprCollection *names,
+						 const char *id);
+
 G_END_DECLS
 
 #endif /* _GNM_EXPR_NAME_H_ */
