@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* format.c - attempts to emulate excel's number formatting ability.
  *
  * Copyright (C) 1998 Chris Lahey, Miguel de Icaza
@@ -23,9 +22,9 @@
  */
 
 #include <gnumeric-config.h>
-#include "gnm-format.h"
-#include "value.h"
-#include "cell.h"
+#include <gnm-format.h>
+#include <value.h>
+#include <cell.h>
 
 #include <goffice/goffice.h>
 #include <glib/gi18n-lib.h>
