@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Gnumeric's extended canvas used to display a pane
  *
@@ -8,38 +7,37 @@
  */
 #include <gnumeric-config.h>
 #include <gnm-i18n.h>
-#include "gnumeric.h"
-#include "gnm-pane-impl.h"
-#include "gnm-pane.h"
+#include <gnumeric.h>
+#include <gnm-pane-impl.h>
+#include <gnm-pane.h>
 
-#include "sheet-control-gui-priv.h"
-#include "gui-util.h"
-#include "gutils.h"
-#include "mstyle.h"
-#include "selection.h"
-#include "parse-util.h"
-#include "ranges.h"
-#include "sheet.h"
-#include "sheet-view.h"
-#include "application.h"
-#include "workbook-view.h"
-#include "wbc-gtk-impl.h"
-#include "workbook.h"
-#include "workbook-cmd-format.h"
-#include "commands.h"
-#include "cmd-edit.h"
-#include "clipboard.h"
-#include "sheet-filter-combo.h"
-#include "widgets/gnm-cell-combo-view.h"
-#include "item-bar.h"
-#include "item-cursor.h"
-#include "item-edit.h"
-#include "item-grid.h"
-#include "gnumeric-conf.h"
+#include <sheet-control-gui-priv.h>
+#include <gui-util.h>
+#include <gutils.h>
+#include <mstyle.h>
+#include <selection.h>
+#include <parse-util.h>
+#include <ranges.h>
+#include <sheet.h>
+#include <sheet-view.h>
+#include <application.h>
+#include <workbook-view.h>
+#include <wbc-gtk-impl.h>
+#include <workbook.h>
+#include <workbook-cmd-format.h>
+#include <commands.h>
+#include <cmd-edit.h>
+#include <clipboard.h>
+#include <sheet-filter-combo.h>
+#include <widgets/gnm-cell-combo-view.h>
+#include <item-bar.h>
+#include <item-cursor.h>
+#include <item-edit.h>
+#include <item-grid.h>
+#include <gnumeric-conf.h>
 
 #include <gsf/gsf-impl-utils.h>
 
-#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
 #include <string.h>
@@ -271,11 +269,10 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *kevent,
 	case GDK_KEY_Page_Up:
 		if (event_state & GDK_CONTROL_MASK) {
 			if (event_state & GDK_SHIFT_MASK) {
-				WorkbookSheetState * old_state = workbook_sheet_state_new(wb);
 				int old_pos = sheet->index_in_wb;
-
-				if (old_pos > 0){
-					workbook_sheet_move(sheet, -1);
+				if (old_pos > 0) {
+					WorkbookSheetState * old_state = workbook_sheet_state_new (wb);
+					workbook_sheet_move (sheet, -1);
 					cmd_reorganize_sheets (wbc, old_state, sheet);
 				}
 			} else {
@@ -296,15 +293,13 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *kevent,
 
 	case GDK_KEY_KP_Page_Down:
 	case GDK_KEY_Page_Down:
-
 		if ((event_state & GDK_CONTROL_MASK) != 0){
 			if ((event_state & GDK_SHIFT_MASK) != 0){
-				WorkbookSheetState * old_state = workbook_sheet_state_new(wb);
-				int num_sheets = workbook_sheet_count(wb);
+				int num_sheets = workbook_sheet_count (wb);
 				gint old_pos = sheet->index_in_wb;
-
-				if (old_pos < num_sheets - 1){
-					workbook_sheet_move(sheet, 1);
+				if (old_pos < num_sheets - 1) {
+					WorkbookSheetState *old_state = workbook_sheet_state_new (wb);
+					workbook_sheet_move (sheet, 1);
 					cmd_reorganize_sheets (wbc, old_state, sheet);
 				}
 			} else {
@@ -1374,7 +1369,7 @@ gnm_pane_find_row (GnmPane const *pane, gint64 y, gint64 *row_origin)
  *     recalculates the visible boundaries.
  *
  * @full_recompute:
- *       if TRUE recompute the pixel offsets of the top left row/col
+ *       if %TRUE recompute the pixel offsets of the top left row/col
  *       else assumes that the pixel offsets of the top left have not changed.
  */
 void
@@ -1728,7 +1723,7 @@ cb_pane_sliding (GnmPane *pane)
  * @pane: The GnmPane managing the scroll
  * @canvas: The Canvas the event comes from
  * @slide_flags:
- * @handler: (scope call): The handler when sliding
+ * @handler: (scope async): The handler when sliding
  * @user_data: closure data
  *
  * Handle a motion event from a @canvas and scroll the @pane
@@ -2143,7 +2138,7 @@ gnm_pane_size_guide_stop (GnmPane *pane)
 /**
  * gnm_pane_size_guide_motion:
  * @p: #GnmPane
- * @vert: TRUE for a vertical guide, FALSE for horizontal
+ * @vert: %TRUE for a vertical guide, %FALSE for horizontal
  * @guide_pos: in unscaled sheet pixel coords
  *
  * Moves the guide line to @guide_pos.
