@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-plugin-service.c: Plugin services - reading XML info, activating, etc.
  *                   (everything independent of plugin loading method)
@@ -7,12 +6,12 @@
  */
 
 #include <gnumeric-config.h>
-#include "gutils.h"
+#include <gutils.h>
 #include <tools/gnm-solver.h>
-#include "func.h"
-#include "gnm-plugin.h"
-#include "gnumeric-conf.h"
-#include "application.h"
+#include <func.h>
+#include <gnm-plugin.h>
+#include <gnumeric-conf.h>
+#include <application.h>
 
 #include <goffice/goffice.h>
 #include <gsf/gsf-impl-utils.h>
@@ -41,7 +40,7 @@ struct GnmPluginServiceFunctionGroup_ {
 
 	GnmFuncGroup *func_group;
 	GnmPluginServiceFunctionGroupCallbacks cbs;
-	char *textdomain;
+	char *tdomain;
 };
 
 static void
@@ -59,8 +58,8 @@ plugin_service_function_group_finalize (GObject *obj)
 	g_slist_free_full (sfg->function_name_list, g_free);
 	sfg->function_name_list = NULL;
 
-	g_free (sfg->textdomain);
-	sfg->textdomain = NULL;
+	g_free (sfg->tdomain);
+	sfg->tdomain = NULL;
 
 	parent_class = g_type_class_peek (GO_TYPE_PLUGIN_SERVICE);
 	parent_class->finalize (obj);
@@ -72,7 +71,7 @@ plugin_service_function_group_read_xml (GOPluginService *service, xmlNode *tree,
 	xmlNode *category_node, *translated_category_node, *functions_node;
 	gchar *category_name, *translated_category_name;
 	GSList *function_name_list = NULL;
-	gchar *textdomain = NULL;
+	gchar *tdomain = NULL;
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	category_node = go_xml_get_child_by_name_no_lang (tree, "category");
@@ -99,7 +98,7 @@ plugin_service_function_group_read_xml (GOPluginService *service, xmlNode *tree,
 	if (functions_node != NULL) {
 		xmlNode *node;
 
-		textdomain = xml2c (go_xml_node_get_cstr (functions_node, "textdomain"));
+		tdomain = xml2c (go_xml_node_get_cstr (functions_node, "textdomain"));
 
 		for (node = functions_node->xmlChildrenNode; node != NULL; node = node->next) {
 			gchar *func_name;
@@ -121,7 +120,7 @@ plugin_service_function_group_read_xml (GOPluginService *service, xmlNode *tree,
 		sfg->category_name = category_name;
 		sfg->translated_category_name = translated_category_name;
 		sfg->function_name_list = function_name_list;
-		sfg->textdomain = textdomain;
+		sfg->tdomain = tdomain;
 	} else {
 		GSList *error_list = NULL;
 
@@ -140,49 +139,45 @@ plugin_service_function_group_read_xml (GOPluginService *service, xmlNode *tree,
 		g_free (translated_category_name);
 		g_slist_free_full (function_name_list, g_free);
 
-		g_free (textdomain);
+		g_free (tdomain);
 	}
 }
 
-static gboolean
-plugin_service_function_group_func_desc_load (GnmFunc const *fn_def,
-					      GnmFuncDescriptor *res)
+static void
+plugin_service_function_group_func_ref_notify (GnmFunc *fn_def,
+					       G_GNUC_UNUSED GParamSpec *pspec,
+					       GOPlugin *plugin)
+{
+	if (gnm_func_get_in_use (fn_def))
+		go_plugin_use_ref (plugin);
+	else
+		go_plugin_use_unref (plugin);
+}
+
+static void
+plugin_service_function_group_func_load_stub (GnmFunc *fn_def,
+					      GOPluginService *service)
 {
-	GOPluginService	*service = gnm_func_get_user_data (fn_def);
 	GnmPluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
 	GOErrorInfo *error = NULL;
 
-	g_return_val_if_fail (fn_def != NULL, FALSE);
+	g_return_if_fail (fn_def != NULL);
 
 	go_plugin_service_load (service, &error);
 	if (error != NULL) {
 		go_error_info_print (error);
 		go_error_info_free (error);
-		return FALSE;
+		return;
 	}
-	if (NULL == sfg->cbs.func_desc_load) {
-                error = go_error_info_new_printf (_("No func_desc_load method.\n"));
+
+	if (!sfg->cbs.load_stub) {
+                error = go_error_info_new_printf (_("No load_stub method.\n"));
 		go_error_info_print (error);
 		go_error_info_free (error);
-		return FALSE;
+		return;
 	}
-	return sfg->cbs.func_desc_load (service,
-					gnm_func_get_name (fn_def, FALSE),
-					res);
-}
 
-static void
-plugin_service_function_group_func_ref_notify (GnmFunc *fn_def, int refcount)
-{
-	GOPluginService *service;
-
-	service = gnm_func_get_user_data (fn_def);
-	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (service));
-	if (refcount == 0) {
-		go_plugin_use_unref (service->plugin);
-	} else {
-		go_plugin_use_ref (service->plugin);
-	}
+	sfg->cbs.load_stub (service, fn_def);
 }
 
 static void
@@ -193,7 +188,7 @@ delayed_ref_notify (GOPlugin *plugin, GnmFunc *fd)
 					      fd);
 
 	/* We cannot do this until after the plugin has been activated.  */
-	plugin_service_function_group_func_ref_notify (fd, 1);
+	plugin_service_function_group_func_ref_notify (fd, NULL, plugin);
 }
 
 static void
@@ -201,40 +196,41 @@ plugin_service_function_group_activate (GOPluginService *service, GOErrorInfo **
 {
 	GnmPluginServiceFunctionGroup *sfg =
 		GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
+	GOPlugin *plugin = go_plugin_service_get_plugin (service);
+	GSList *l;
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	sfg->func_group = gnm_func_group_fetch (sfg->category_name,
 						sfg->translated_category_name);
 	if (gnm_debug_flag ("plugin-func"))
 		g_printerr ("Activating group %s\n", sfg->category_name);
-	GO_SLIST_FOREACH
-		(sfg->function_name_list, char, fname,
-		 GnmFunc *fd;
 
-		 fd = gnm_func_lookup (fname, NULL);
-		 if (fd) {
-#if 0
-			 g_printerr ("Reusing placeholder for %s\n", fname);
-#endif
-		 } else {
-			 fd = gnm_func_add_placeholder (NULL, fname, "?");
-		 }
-		 if (fd->flags & GNM_FUNC_IS_PLACEHOLDER) {
-			 gnm_func_set_user_data (fd, service);
-			 gnm_func_upgrade_placeholder
-				 (fd, sfg->func_group,
-				  sfg->textdomain,
-				  plugin_service_function_group_func_desc_load,
-				  plugin_service_function_group_func_ref_notify);
-			 if (fd->usage_count > 0)
-				 g_signal_connect (go_plugin_service_get_plugin (service),
-						   "state_changed",
-						   G_CALLBACK (delayed_ref_notify),
-						   fd);
-		 } else {
-			 g_warning ("Multiple definitions of function %s -- this cannot be good!", fname);
-		 }
-	);
+	for (l = sfg->function_name_list; l; l = l->next) {
+		const char *fname = l->data;
+		GnmFunc *func = gnm_func_lookup_or_add_placeholder (fname);
+
+		gnm_func_set_stub (func);
+		gnm_func_set_translation_domain (func, sfg->tdomain);
+		gnm_func_set_function_group (func, sfg->func_group);
+		// Clear localized_name so we can deduce the proper name.
+		//gnm_func_set_localized_name (func, NULL);
+
+		g_signal_connect
+			(func, "notify::in-use",
+			 G_CALLBACK (plugin_service_function_group_func_ref_notify),
+			 plugin);
+
+		g_signal_connect
+			(func, "load-stub",
+			 G_CALLBACK (plugin_service_function_group_func_load_stub),
+			 service);
+
+		if (gnm_func_get_in_use (func))
+			g_signal_connect (plugin,
+					  "state_changed",
+					  G_CALLBACK (delayed_ref_notify),
+					  func);
+	}
 	service->is_active = TRUE;
 }
 
@@ -242,14 +238,30 @@ static void
 plugin_service_function_group_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	GnmPluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
+	GOPlugin *plugin = go_plugin_service_get_plugin (service);
+	GSList *l;
 
 	if (gnm_debug_flag ("plugin-func"))
 		g_printerr ("Deactivating group %s\n", sfg->category_name);
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
-	GO_SLIST_FOREACH (sfg->function_name_list, char, fname,
-		gnm_func_free (gnm_func_lookup (fname, NULL));
-	);
+
+	for (l = sfg->function_name_list; l; l = l->next) {
+		const char *fname = l->data;
+		GnmFunc *func = gnm_func_lookup (fname, NULL);
+
+		// This should not happen, but if it were to, having a handler
+		// of some other object is not going to be good.
+		if (gnm_func_get_in_use (func))
+			g_signal_handlers_disconnect_by_func
+				(plugin, G_CALLBACK (delayed_ref_notify), func);
+
+		// Someone else might hold a ref so make sure the object
+		// becomes inaccessible via gnm_func_lookup
+		gnm_func_dispose (func);
+
+		g_object_unref (func);
+	}
 	service->is_active = FALSE;
 }
 
@@ -280,7 +292,7 @@ plugin_service_function_group_init (GnmPluginServiceFunctionGroup *s)
 	s->translated_category_name = NULL;
 	s->function_name_list = NULL;
 	s->func_group = NULL;
-	s->textdomain = NULL;
+	s->tdomain = NULL;
 }
 
 static void
@@ -333,7 +345,7 @@ plugin_service_ui_finalize (GObject *obj)
 
 	g_free (service_ui->file_name);
 	service_ui->file_name = NULL;
-	g_slist_free_full (service_ui->actions, (GDestroyNotify)gnm_action_free);
+	g_slist_free_full (service_ui->actions, (GDestroyNotify)gnm_action_unref);
 	service_ui->actions = NULL;
 
 	parent_class = g_type_class_peek (GO_TYPE_PLUGIN_SERVICE);
@@ -413,7 +425,8 @@ plugin_service_ui_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo
 			if (!go_xml_node_get_bool (ptr, "always_available", &always_available))
 				always_available = FALSE;
 			action = gnm_action_new (name, label, icon, always_available,
-				(GnmActionHandler) cb_ui_service_activate);
+						 (GnmActionHandler) cb_ui_service_activate,
+						 service, NULL);
 			if (NULL != name) xmlFree (name);
 			g_free (label);
 			if (NULL != icon) xmlFree (icon);
@@ -433,7 +446,7 @@ plugin_service_ui_activate (GOPluginService *service, GOErrorInfo **ret_error)
 	PluginServiceUI *service_ui = GNM_PLUGIN_SERVICE_UI (service);
 	const char *uifile = service_ui->file_name;
 	char *xml_ui, *group_name;
-	char const *textdomain;
+	char const *tdomain;
 	GError *error = NULL;
 	GsfInput *src;
 	size_t len;
@@ -468,11 +481,11 @@ plugin_service_ui_activate (GOPluginService *service, GOErrorInfo **ret_error)
 	if (!xml_ui)
 		goto err;
 
-	textdomain = go_plugin_get_textdomain (service->plugin);
+	tdomain = go_plugin_get_textdomain (service->plugin);
 	group_name = g_strconcat (go_plugin_get_id (service->plugin), service->id, NULL);
 	service_ui->layout_id = gnm_app_add_extra_ui (group_name,
 		service_ui->actions,
-		xml_ui, textdomain, service);
+		xml_ui, tdomain);
 	g_free (group_name);
 	g_free (xml_ui);
 	g_object_unref (src);
@@ -547,7 +560,8 @@ struct GnmPluginServiceSolver_ {
 };
 
 static GnmSolver *
-cb_load_and_create (GnmSolverFactory *factory, GnmSolverParameters *param)
+cb_load_and_create (GnmSolverFactory *factory, GnmSolverParameters *param,
+		    gpointer data)
 {
 	PluginServiceSolver *ssol =
 		g_object_get_data (G_OBJECT (factory), "ssol");
@@ -562,7 +576,7 @@ cb_load_and_create (GnmSolverFactory *factory, GnmSolverParameters *param)
 		return NULL;
 	}
 
-	res = ssol->cbs.creator (factory, param);
+	res = ssol->cbs.creator (factory, param, data);
 	if (res) {
 		go_plugin_use_ref (service->plugin);
 		g_object_set_data_full (G_OBJECT (res),
@@ -575,7 +589,8 @@ cb_load_and_create (GnmSolverFactory *factory, GnmSolverParameters *param)
 
 static gboolean
 cb_load_and_functional (GnmSolverFactory *factory,
-			WBCGtk *wbcg)
+			WBCGtk *wbcg,
+			gpointer data)
 {
 	PluginServiceSolver *ssol =
 		g_object_get_data (G_OBJECT (factory), "ssol");
@@ -591,7 +606,7 @@ cb_load_and_functional (GnmSolverFactory *factory,
 	}
 
 	functional = ssol->cbs.functional;
-	return (functional == NULL || functional (factory, wbcg));
+	return (functional == NULL || functional (factory, wbcg, data));
 }
 
 static void
@@ -659,7 +674,9 @@ plugin_service_solver_read_xml (GOPluginService *service, xmlNode *tree,
 							CXML2C (s_name),
 							type,
 							cb_load_and_create,
-							cb_load_and_functional);
+							cb_load_and_functional,
+							NULL,
+							NULL);
 		g_object_set_data (G_OBJECT (ssol->factory), "ssol", ssol);
 	}
 	xmlFree (s_id);
@@ -737,26 +754,29 @@ function_group_loader_data_free (gpointer data)
 	g_free (ld);
 }
 
-static gboolean
-gnm_plugin_loader_module_func_desc_load (GOPluginService *service,
-					 char const *name,
-					 GnmFuncDescriptor *res)
+static void
+gnm_plugin_loader_module_func_load_stub (GOPluginService *service,
+					 GnmFunc *func)
 {
 	ServiceLoaderDataFunctionGroup *loader_data;
-	gpointer func_index_ptr;
+	gpointer index_ptr;
+	GnmFuncDescriptor *desc;
+	const char *name;
 
-	g_return_val_if_fail (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (service), FALSE);
-	g_return_val_if_fail (name != NULL, FALSE);
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (service));
+	g_return_if_fail (GNM_IS_FUNC (func));
 
+	name = gnm_func_get_name (func, FALSE);
 	loader_data = g_object_get_data (G_OBJECT (service), "loader_data");
-	if (g_hash_table_lookup_extended (loader_data->function_indices, (gpointer) name,
-	                                  NULL, &func_index_ptr)) {
-		int i = GPOINTER_TO_INT (func_index_ptr);
-		*res = loader_data->module_fn_info_array[i];
-		return TRUE;
-	}
-	return FALSE;
+	if (!g_hash_table_lookup_extended (loader_data->function_indices,
+					   (gpointer)name,
+					   NULL, &index_ptr))
+		return; // Failed
+
+	desc = loader_data->module_fn_info_array + GPOINTER_TO_INT (index_ptr);
+	gnm_func_set_from_desc (func, desc);
 }
+
 static void
 gnm_plugin_loader_module_load_service_function_group (GOPluginLoader  *loader,
 						      GOPluginService *service,
@@ -778,7 +798,7 @@ gnm_plugin_loader_module_load_service_function_group (GOPluginLoader  *loader,
 		gint i;
 
 		cbs = go_plugin_service_get_cbs (service);
-		cbs->func_desc_load = &gnm_plugin_loader_module_func_desc_load;
+		cbs->load_stub = &gnm_plugin_loader_module_func_load_stub;
 
 		loader_data = g_new (ServiceLoaderDataFunctionGroup, 1);
 		loader_data->module_fn_info_array = module_fn_info_array;
@@ -945,7 +965,7 @@ gplm_service_unload (GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err)
 {
 	if (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (s)) {
 		GnmPluginServiceFunctionGroupCallbacks *cbs = go_plugin_service_get_cbs (s);
-		cbs->func_desc_load = NULL;
+		cbs->load_stub = NULL;
 	} else if (GNM_IS_PLUGIN_SERVICE_UI (s)) {
 		GnmPluginServiceUICallbacks *cbs = go_plugin_service_get_cbs (s);
 		cbs->plugin_func_exec_action = NULL;
@@ -973,6 +993,22 @@ GSF_CLASS_FULL (GnmPluginLoaderModule, gnm_plugin_loader_module,
 
 /****************************************************************************/
 
+/**
+ * gnm_plugins_service_init: (skip)
+ */
+void
+gnm_plugins_service_init (void)
+{
+	go_plugin_service_define ("function_group",
+		&gnm_plugin_service_function_group_get_type);
+	go_plugin_service_define ("ui",
+		&gnm_plugin_service_ui_get_type);
+	go_plugin_service_define ("solver",
+		&gnm_plugin_service_solver_get_type);
+	go_plugin_loader_module_register_version ("gnumeric", GNM_VERSION_FULL);
+}
+
+
 void
 gnm_plugins_init (GOCmdContext *context)
 {
