@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * gnm-so-line.c: Lines, arrows, arcs
@@ -22,11 +21,11 @@
  */
 
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "gnm-so-line.h"
-#include "sheet-object-impl.h"
-#include "gutils.h"
-#include "xml-sax.h"
+#include <gnumeric.h>
+#include <gnm-so-line.h>
+#include <sheet-object-impl.h>
+#include <gutils.h>
+#include <xml-sax.h>
 
 #include <goffice/goffice.h>
 #include <gsf/gsf-impl-utils.h>
