@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * gnm-so-path.c
  *
@@ -21,13 +20,13 @@
  */
 
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "application.h"
-#include "gnm-so-path.h"
-#include "sheet-object-impl.h"
-#include "sheet.h"
-#include "gutils.h"
-#include "xml-sax.h"
+#include <gnumeric.h>
+#include <application.h>
+#include <gnm-so-path.h>
+#include <sheet-object-impl.h>
+#include <sheet.h>
+#include <gutils.h>
+#include <xml-sax.h>
 
 #include <goffice/goffice.h>
 #include <gsf/gsf-impl-utils.h>
@@ -59,7 +58,7 @@ typedef struct {
 typedef SheetObjectClass GnmSOPathClass;
 
 #ifdef GNM_WITH_GTK
-#include "gnm-pane.h"
+#include <gnm-pane.h>
 
 typedef struct {
 	SheetObjectView	base;
