@@ -1,8 +1,7 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_GUTILS_H_
 # define _GNM_GUTILS_H_
 
-#include "gnumeric.h"
+#include <gnumeric.h>
 #include <goffice/goffice.h>
 #include <numbers.h>
 
@@ -62,6 +61,18 @@ void gnm_hash_table_foreach_ordered (GHashTable *h,
 
 void gnm_xml_in_doc_dispose_on_exit (GsfXMLInDoc **pdoc);
 
+Sheet *gnm_file_saver_get_sheet (GOFileSaver const *fs,
+				 WorkbookView const *wbv);
+GPtrArray *gnm_file_saver_get_sheets (GOFileSaver const *fs,
+				      WorkbookView const *wbv,
+				      gboolean default_all);
+
+gboolean gnm_file_saver_common_export_option (GOFileSaver const *fs,
+					      Workbook const *wb,
+					      const char *key,
+					      const char *value,
+					      GError **err);
+
 G_END_DECLS
 
 #endif /* _GNM_GUTILS_H_ */
