@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * io-context-gtk.c : gtk based io error context.
@@ -11,17 +10,16 @@
  * (C) 2002 Jon K Hellan
  */
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "gui-util.h"
-#include "io-context-gtk.h"
+#include <gnumeric.h>
+#include <gui-util.h>
+#include <io-context-gtk.h>
 #include <goffice/goffice.h>
-#include "application.h"
-#include "libgnumeric.h"
-#include "dialogs.h"
-#include "gnm-i18n.h"
+#include <application.h>
+#include <libgnumeric.h>
+#include <dialogs/dialogs.h>
+#include <gnm-i18n.h>
 
 #include <gsf/gsf-impl-utils.h>
-#include <gtk/gtk.h>
 #include <stdlib.h>
 #include <string.h>
 
