@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * A canvas item implementing row/col headers with support for outlining.
  *
@@ -8,26 +7,25 @@
  */
 
 #include <gnumeric-config.h>
-#include "gnm-i18n.h"
-#include "gnumeric.h"
-#include "item-bar.h"
-#include "gnm-pane-impl.h"
+#include <gnm-i18n.h>
+#include <gnumeric.h>
+#include <item-bar.h>
+#include <gnm-pane-impl.h>
 
-#include "style-color.h"
-#include "sheet.h"
-#include "sheet-control-gui.h"
-#include "sheet-control-gui-priv.h"
-#include "application.h"
-#include "selection.h"
-#include "wbc-gtk-impl.h"
-#include "gui-util.h"
-#include "parse-util.h"
-#include "commands.h"
-#include "gutils.h"
+#include <style-color.h>
+#include <sheet.h>
+#include <sheet-control-gui.h>
+#include <sheet-control-gui-priv.h>
+#include <application.h>
+#include <selection.h>
+#include <wbc-gtk-impl.h>
+#include <gui-util.h>
+#include <parse-util.h>
+#include <commands.h>
+#include <gutils.h>
 
 #include <goffice/goffice.h>
 #include <gsf/gsf-impl-utils.h>
-#include <gtk/gtk.h>
 #define GNUMERIC_ITEM "BAR"
 
 #include <string.h>
@@ -738,9 +736,10 @@ item_bar_draw_region (GocItem const *item, cairo_t *cr,
 								cairo_move_to (cr, left+3,	    bottom+size/2);
 								cairo_line_to (cr, left+size-4, bottom+size/2);
 							}
-						} else if (level > 0)
+						} else if (level > 0) {
 							cairo_move_to (cr, pos,      top+pixels/2);
 							cairo_line_to (cr, pos+len,  top+pixels/2);
+						}
 					}
 					cairo_stroke (cr);
 					cairo_restore (cr);
@@ -775,7 +774,7 @@ item_bar_distance (GocItem *item, double x, double y,
  * NOTE : this could easily be optimized.  We need not start at 0 every time.
  *        We could potentially use the routines in gnm-pane.
  *
- * Returns non-NULL if point (@x,@y) is on a division
+ * Returns non-%NULL if point (@x,@y) is on a division
  **/
 static ColRowInfo const *
 is_pointer_on_division (GnmItemBar const *ib, gint64 x, gint64 y,
