@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * libgnumeric.c: global initialization and management code
  *
@@ -23,44 +22,43 @@
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "gnumeric.h"
-#include "libgnumeric.h"
-#include "gutils.h"
+#include <gnumeric.h>
+#include <libgnumeric.h>
+#include <gutils.h>
 
-#include "application.h"
-#include "stf.h"
-#include "gnm-format.h"
-#include "command-context.h"
-#include "command-context-stderr.h"
-#include "workbook.h"
-#include "sheet-object.h"
-#include "number-match.h"
-#include "expr-name.h"
-#include "func.h"
-#include "print-info.h"
-#include "style-font.h"
-#include "mstyle.h"
-#include "style-border.h"
-#include "style-color.h"
-#include "print.h"
-#include "dependent.h"
-#include "sheet-autofill.h"
-#include "sheet-private.h"
-#include "xml-sax.h"
-#include "clipboard.h"
-#include "gui-clipboard.h"
-#include "value.h"
-#include "expr.h"
-#include "expr-deriv.h"
-#include "parse-util.h"
-#include "rendered-value.h"
-#include "gnumeric-conf.h"
-#include "gnm-plugin.h"
-#include "mathfunc.h"
-#include "hlink.h"
-#include "wbc-gtk-impl.h"
-#include "gnmresources.h"
-#include "dialogs/embedded-ui.h"
+#include <application.h>
+#include <stf.h>
+#include <gnm-format.h>
+#include <command-context.h>
+#include <command-context-stderr.h>
+#include <workbook.h>
+#include <sheet-object.h>
+#include <number-match.h>
+#include <expr-name.h>
+#include <func.h>
+#include <print-info.h>
+#include <style-font.h>
+#include <mstyle.h>
+#include <style-border.h>
+#include <style-color.h>
+#include <print.h>
+#include <dependent.h>
+#include <sheet-autofill.h>
+#include <sheet-private.h>
+#include <xml-sax.h>
+#include <clipboard.h>
+#include <gui-clipboard.h>
+#include <value.h>
+#include <expr.h>
+#include <expr-deriv.h>
+#include <parse-util.h>
+#include <rendered-value.h>
+#include <gnumeric-conf.h>
+#include <gnm-plugin.h>
+#include <mathfunc.h>
+#include <hlink.h>
+#include <wbc-gtk-impl.h>
+#include <gnmresources.h>
 #include <goffice/goffice.h>
 
 #ifdef HAVE_SYS_RESOURCE_H
@@ -128,9 +126,6 @@ fake_gtk_icon_theme_add_resource_path (GtkIconTheme G_GNUC_UNUSED *theme,
 
 #endif
 
-/* TODO : get rid of this monstrosity */
-gboolean initial_workbook_open_complete = FALSE;
-
 static gboolean param_show_version = FALSE;
 static char *param_lib_dir  = NULL;
 static char *param_data_dir = NULL;
@@ -300,14 +295,8 @@ gnm_init (void)
 		gtk_icon_theme_add_resource_path (gtk_icon_theme_get_default (),
 						  "/org/gnumeric/gnumeric/icons");
 	}
-	gnm_register_ui_files ();
-	go_plugin_service_define ("function_group",
-		&gnm_plugin_service_function_group_get_type);
-	go_plugin_service_define ("ui",
-		&gnm_plugin_service_ui_get_type);
-	go_plugin_service_define ("solver",
-		&gnm_plugin_service_solver_get_type);
-	go_plugin_loader_module_register_version ("gnumeric", GNM_VERSION_FULL);
+
+	gnm_plugins_service_init ();
 
 	g_object_new (GNM_APP_TYPE, NULL);
 	mathfunc_init ();
@@ -319,17 +308,17 @@ gnm_init (void)
 
 	value_init ();
 	parse_util_init ();
-	_gnm_expr_init ();
+	gnm_expr_init_ ();
 	gnm_sheet_cell_init ();
 	clipboard_init ();
 	gui_clipboard_init ();
 	dependent_types_init ();
 	gnm_rendered_value_init ();
-	functions_init ();
+	gnm_func_init_ ();
 	print_init ();
 	gnm_autofill_init ();
 	sheet_objects_init ();
-	_gnm_hlink_init ();
+	gnm_hlink_init_ ();
 
 	/* The statically linked in file formats */
 	gnm_xml_sax_read_init ();
@@ -361,23 +350,26 @@ gnm_shutdown (void)
 
 	gnm_autofill_shutdown ();
 	print_shutdown ();
-	functions_shutdown ();
+	gnm_func_shutdown_ ();
 
 	gnm_rendered_value_shutdown ();
 	dependent_types_shutdown ();
 	gui_clipboard_shutdown ();
 	clipboard_shutdown ();
 	gnm_sheet_cell_shutdown ();
-	_gnm_expr_deriv_shutdown ();
-	_gnm_expr_shutdown ();
+	gnm_expr_deriv_shutdown_ ();
+	gnm_expr_shutdown_ ();
 	parse_util_shutdown ();
 	value_shutdown ();
 
+	// The style leak printer may access font/border/color info so
+	// shut styles down first.
+	gnm_style_shutdown ();
 	gnm_font_shutdown ();
 	gnm_border_shutdown ();
 	gnm_color_shutdown ();
+
 	gnm_conf_shutdown ();
-	gnm_style_shutdown ();
 
 	_gnm_unregister_resource ();
 	libgoffice_shutdown ();
