@@ -1,11 +1,10 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_MATHFUNC_H_
 # define _GNM_MATHFUNC_H_
 
-#include "numbers.h"
+#include <numbers.h>
 #include <math.h>
 #include <glib.h>
-#include "gnumeric.h"
+#include <gnumeric.h>
 
 G_BEGIN_DECLS
 
@@ -21,6 +20,7 @@ G_BEGIN_DECLS
 /* The following are very good given a good compiler.  */
 #define M_LN2gnum   GNM_const(0.693147180559945309417232121458176568075500134360255254120680009493393621969694715605863326996419)
 #define M_LN10gnum  GNM_const(2.302585092994045684017991454684364207601101488628772976033327900967572609677352480235997205089598)
+#define M_LN10INVgnum  GNM_const(0.434294481903251827651128918916605082294397005803666566114)
 #define M_SQRT2gnum GNM_const(1.414213562373095048801688724209698078569671875376948073176679737990732478462107038850387534327642)
 #define	M_Egnum         GNM_const(2.718281828459045235360287471352662497757247)
 #define M_LN_SQRT_2PI   GNM_const(0.918938533204672741780329736406)  /* log(sqrt(2*pi)) */
@@ -37,6 +37,8 @@ gnm_float logspace_sub (gnm_float logx, gnm_float logy);
 gnm_float gnm_owent (gnm_float h, gnm_float a);
 gnm_float gnm_logcf (gnm_float x, gnm_float i, gnm_float d);
 gnm_float expmx2h (gnm_float x);
+gnm_float gnm_agm(gnm_float a, gnm_float b);
+gnm_float gnm_lambert_w(gnm_float x, int k);
 
 /* "d": density.  */
 /* "p": distribution function.  */
@@ -100,7 +102,6 @@ gnm_float qnbinom (gnm_float p, gnm_float n, gnm_float psuc, gboolean lower_tail
 /* Hyper-geometrical distribution.  */
 gnm_float dhyper (gnm_float x, gnm_float r, gnm_float b, gnm_float n, gboolean give_log);
 gnm_float phyper (gnm_float x, gnm_float r, gnm_float b, gnm_float n, gboolean lower_tail, gboolean log_p);
-gnm_float qhyper (gnm_float p, gnm_float r, gnm_float b, gnm_float n, gboolean lower_tail, gboolean log_p);
 
 /* Geometric distribution.  */
 gnm_float dgeom (gnm_float x, gnm_float psuc, gboolean give_log);
@@ -124,13 +125,17 @@ gnm_float qtukey(gnm_float p, gnm_float nmeans, gnm_float df, gnm_float nranges,
 
 /* Matrix functions. */
 
-typedef struct {
+GType gnm_matrix_get_type (void);
+
+struct GnmMatrix_ {
+	int ref_count;
 	gnm_float **data;   /* [y][x] */
 	int cols, rows;
-} GnmMatrix;
+};
 
 GnmMatrix *gnm_matrix_new (int rows, int cols); /* Note the order: y then x. */
-void gnm_matrix_free (GnmMatrix *m);
+GnmMatrix *gnm_matrix_ref (GnmMatrix *m);
+void gnm_matrix_unref (GnmMatrix *m);
 GnmMatrix *gnm_matrix_from_value (GnmValue const *v, GnmValue **perr, GnmEvalPos const *ep);
 GnmValue *gnm_matrix_to_value (GnmMatrix const *m);
 gboolean gnm_matrix_is_empty (GnmMatrix const *m);
@@ -138,6 +143,21 @@ gboolean gnm_matrix_is_empty (GnmMatrix const *m);
 void gnm_matrix_multiply (GnmMatrix *C, const GnmMatrix *A, const GnmMatrix *B);
 
 gboolean gnm_matrix_eigen (GnmMatrix const *m, GnmMatrix *EIG, gnm_float *eigenvalues);
+
+gboolean gnm_matrix_modified_cholesky (GnmMatrix const *A,
+				       GnmMatrix *L,
+				       gnm_float *D,
+				       gnm_float *E,
+				       int *P);
+
+GORegressionResult gnm_linear_solve_posdef (GnmMatrix const *A, const gnm_float *b,
+					    gnm_float *x);
+
+GORegressionResult gnm_linear_solve (GnmMatrix const *A, const gnm_float *b,
+				     gnm_float *x);
+
+GORegressionResult gnm_linear_solve_multiple (GnmMatrix const *A, GnmMatrix *B);
+
 /* ------------------------------------------------------------------------- */
 
 void mathfunc_init (void);
