@@ -8,25 +8,25 @@
  *   Morten Welinder <terra@gnome.org>
  */
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "style.h"
+#include <gnumeric.h>
+#include <style.h>
 
-#include "sheet-style.h"
-#include "style-border.h"
-#include "style-font.h"
-#include "style-color.h"
-#include "style-conditions.h"
-#include "validation.h"
-#include "pattern.h"
-#include "hlink.h"
-#include "input-msg.h"
-#include "application.h"
-#include "parse-util.h"
-#include "expr.h"
-#include "value.h"
-#include "gutils.h"
-#include "ranges.h"
-#include "gnumeric-conf.h"
+#include <sheet-style.h>
+#include <style-border.h>
+#include <style-font.h>
+#include <style-color.h>
+#include <style-conditions.h>
+#include <validation.h>
+#include <pattern.h>
+#include <hlink.h>
+#include <input-msg.h>
+#include <application.h>
+#include <parse-util.h>
+#include <expr.h>
+#include <value.h>
+#include <gutils.h>
+#include <ranges.h>
+#include <gnumeric-conf.h>
 #include <goffice/goffice.h>
 #include <string.h>
 
@@ -1290,9 +1290,9 @@ gnm_style_is_element_set (GnmStyle const *style, GnmStyleElement elem)
 
 /**
  * gnm_style_is_complete:
- * @style: #GnmStyle
+ * @style: #GnmStyle to query
  *
- * Returns TRUE if all elements are set.
+ * Returns: %TRUE if all elements are set.
  **/
 gboolean
 gnm_style_is_complete (GnmStyle const *style)
@@ -1360,6 +1360,13 @@ gnm_style_merge_element (GnmStyle *dst, GnmStyle const *src, GnmStyleElement ele
 	}
 }
 
+/**
+ * gnm_style_set_font_color:
+ * @style: #GnmStyle to change
+ * @col: (transfer full): #GnmColor
+ *
+ * Set the color used for fonts.
+ */
 void
 gnm_style_set_font_color (GnmStyle *style, GnmColor *col)
 {
@@ -1378,13 +1385,12 @@ gnm_style_set_font_color (GnmStyle *style, GnmColor *col)
 
 /**
  * gnm_style_set_back_color:
- * @style: #GnmStyle
- * @col: #GnmColor
+ * @style: #GnmStyle to change
+ * @col: (transfer full): #GnmColor
  *
  * Assigns @col as the background of @style.
  *
- * NOTE : the background colour is only visibile if
- *	GnmStyle::pattern > 0
+ * NOTE: the background colour is only visibile if GnmStyle::pattern > 0
  **/
 void
 gnm_style_set_back_color (GnmStyle *style, GnmColor *col)
@@ -1400,6 +1406,14 @@ gnm_style_set_back_color (GnmStyle *style, GnmColor *col)
 	style->color.back = col;
 	gnm_style_clear_pango (style);
 }
+
+/**
+ * gnm_style_set_pattern_color:
+ * @style: #GnmStyle to change
+ * @col: (transfer full): #GnmColor
+ *
+ * Set the color used for pattern.
+ */
 void
 gnm_style_set_pattern_color (GnmStyle *style, GnmColor *col)
 {
@@ -1415,6 +1429,12 @@ gnm_style_set_pattern_color (GnmStyle *style, GnmColor *col)
 	gnm_style_clear_pango (style);
 }
 
+/**
+ * gnm_style_get_font_color:
+ * @style: #GnmStyle to query
+ *
+ * Returns: (transfer none) (nullable): #GnmColor used for font.
+ */
 GnmColor *
 gnm_style_get_font_color (GnmStyle const *style)
 {
@@ -1423,6 +1443,12 @@ gnm_style_get_font_color (GnmStyle const *style)
 	return style->color.font;
 }
 
+/**
+ * gnm_style_get_back_color:
+ * @style: #GnmStyle to query
+ *
+ * Returns: (transfer none) (nullable): #GnmColor used for background.
+ */
 GnmColor *
 gnm_style_get_back_color (GnmStyle const *style)
 {
@@ -1431,6 +1457,12 @@ gnm_style_get_back_color (GnmStyle const *style)
 	return style->color.back;
 }
 
+/**
+ * gnm_style_get_pattern_color:
+ * @style: #GnmStyle to query
+ *
+ * Returns: (transfer none) (nullable): #GnmColor used for pattern.
+ */
 GnmColor *
 gnm_style_get_pattern_color (GnmStyle const *style)
 {
@@ -1439,6 +1471,12 @@ gnm_style_get_pattern_color (GnmStyle const *style)
 	return style->color.pattern;
 }
 
+/**
+ * gnm_style_set_border:
+ * @style: #GnmStyle to change
+ * @elem: Border element
+ * @border: (transfer full) (nullable): new #GnmBorder for @style.
+ */
 void
 gnm_style_set_border (GnmStyle *style, GnmStyleElement elem,
 		      GnmBorder *border)
@@ -1451,8 +1489,7 @@ gnm_style_set_border (GnmStyle *style, GnmStyleElement elem,
 		elem_changed (style, elem);
 		elem_set (style, elem);
 		elem -= MSTYLE_BORDER_TOP;
-		if (style->borders[elem])
-			gnm_style_border_unref (style->borders[elem]);
+		gnm_style_border_unref (style->borders[elem]);
 		style->borders[elem] = border;
 		break;
 	default:
@@ -1461,6 +1498,14 @@ gnm_style_set_border (GnmStyle *style, GnmStyleElement elem,
 	}
 }
 
+/**
+ * gnm_style_get_border:
+ * @style: #GnmStyle to query
+ * @elem: Border element
+ *
+ * Returns: (transfer none) (nullable): The #GnmBorder for a single
+ * border element.
+ */
 GnmBorder *
 gnm_style_get_border (GnmStyle const *style, GnmStyleElement elem)
 {
@@ -1476,6 +1521,11 @@ gnm_style_get_border (GnmStyle const *style, GnmStyleElement elem)
 	}
 }
 
+/**
+ * gnm_style_set_pattern:
+ * @style: #GnmStyle to change
+ * @pattern: pattern code
+ **/
 void
 gnm_style_set_pattern (GnmStyle *style, int pattern)
 {
@@ -1499,10 +1549,10 @@ gnm_style_get_pattern (GnmStyle const *style)
 
 /**
  * gnm_style_get_font:
- * @style: #GnmStyle
+ * @style: #GnmStyle to query
  * @context: #PangoContext
  *
- * Returns: (transfer none):
+ * Returns: (transfer none): GnmFont implied by @style.
  **/
 GnmFont *
 gnm_style_get_font (GnmStyle const *style, PangoContext *context)
@@ -1546,9 +1596,8 @@ gnm_style_get_font (GnmStyle const *style, PangoContext *context)
 
 /**
  * gnm_style_set_font_name:
- * @style: the style to change
+ * @style: #GnmStyle to change
  * @name: the font name as a string
- *
  */
 void
 gnm_style_set_font_name (GnmStyle *style, char const *name)
@@ -1581,6 +1630,11 @@ gnm_style_get_font_name (GnmStyle const *style)
 	return style->font_detail.name->str;
 }
 
+/**
+ * gnm_style_set_font_bold:
+ * @style: #GnmStyle to change
+ * @bold: %TRUE for bold, %FALSE for regular
+ */
 void
 gnm_style_set_font_bold (GnmStyle *style, gboolean bold)
 {
@@ -1608,6 +1662,11 @@ gnm_style_get_font_bold (GnmStyle const *style)
 	return style->font_detail.bold;
 }
 
+/**
+ * gnm_style_set_font_italic:
+ * @style: #GnmStyle to change
+ * @italic: %TRUE for italic, %FALSE for regular
+ */
 void
 gnm_style_set_font_italic (GnmStyle *style, gboolean italic)
 {
@@ -1620,6 +1679,12 @@ gnm_style_set_font_italic (GnmStyle *style, gboolean italic)
 	gnm_style_clear_pango (style);
 }
 
+/**
+ * gnm_style_get_font_italic:
+ * @style: #GnmStyle to query
+ *
+ * Returns: %TRUE if the style has an italic font.
+ */
 gboolean
 gnm_style_get_font_italic (GnmStyle const *style)
 {
@@ -1629,6 +1694,11 @@ gnm_style_get_font_italic (GnmStyle const *style)
 	return style->font_detail.italic;
 }
 
+/**
+ * gnm_style_set_font_uline:
+ * @style: #GnmStyle to change
+ * @ul: #GnmUnderline specifying type of underlining
+ **/
 void
 gnm_style_set_font_uline (GnmStyle *style, GnmUnderline const underline)
 {
@@ -1641,6 +1711,12 @@ gnm_style_set_font_uline (GnmStyle *style, GnmUnderline const underline)
 	gnm_style_clear_pango (style);
 }
 
+/**
+ * gnm_style_get_font_uline:
+ * @style: #GnmStyle to query
+ *
+ * Returns: #GnmUnderline specifying type of underlining
+ **/
 GnmUnderline
 gnm_style_get_font_uline (GnmStyle const *style)
 {
@@ -1650,6 +1726,11 @@ gnm_style_get_font_uline (GnmStyle const *style)
 	return style->font_detail.underline;
 }
 
+/**
+ * gnm_style_set_font_strike:
+ * @style: #GnmStyle to change
+ * @strike: %TRUE for strikethrough, %FALSE for regular
+ */
 void
 gnm_style_set_font_strike (GnmStyle *style, gboolean strikethrough)
 {
@@ -1661,6 +1742,12 @@ gnm_style_set_font_strike (GnmStyle *style, gboolean strikethrough)
 	gnm_style_clear_pango (style);
 }
 
+/**
+ * gnm_style_get_font_strike:
+ * @style: #GnmStyle to query
+ *
+ * Returns: %TRUE for strikethrough, %FALSE for regular
+ */
 gboolean
 gnm_style_get_font_strike (GnmStyle const *style)
 {
@@ -1669,6 +1756,11 @@ gnm_style_get_font_strike (GnmStyle const *style)
 	return style->font_detail.strikethrough;
 }
 
+/**
+ * gnm_style_set_font_script:
+ * @style: #GnmStyle to change
+ * @script: #GOFontScript specifying super or subscript
+ **/
 void
 gnm_style_set_font_script (GnmStyle *style, GOFontScript script)
 {
@@ -1679,6 +1771,12 @@ gnm_style_set_font_script (GnmStyle *style, GOFontScript script)
 	gnm_style_clear_pango (style);
 }
 
+/**
+ * gnm_style_get_font_script:
+ * @style: #GnmStyle to query
+ *
+ * Returns: #GOFontScript specifying super or subscript
+ **/
 GOFontScript
 gnm_style_get_font_script (GnmStyle const *style)
 {
@@ -1688,6 +1786,11 @@ gnm_style_get_font_script (GnmStyle const *style)
 	return style->font_detail.script;
 }
 
+/**
+ * gnm_style_set_font_size:
+ * @style: #GnmStyle to change
+ * @size: Font size in points
+ **/
 void
 gnm_style_set_font_size (GnmStyle *style, double size)
 {
@@ -1700,6 +1803,12 @@ gnm_style_set_font_size (GnmStyle *style, double size)
 	gnm_style_clear_pango (style);
 }
 
+/**
+ * gnm_style_get_font_size:
+ * @style: #GnmStyle to query
+ *
+ * Returns: Font size in points
+ **/
 double
 gnm_style_get_font_size (GnmStyle const *style)
 {
@@ -1709,22 +1818,26 @@ gnm_style_get_font_size (GnmStyle const *style)
 	return style->font_detail.size;
 }
 
+/**
+ * gnm_style_set_format:
+ * @style: #GnmStyle to change
+ * @fmt: #GOFormat
+ */
 void
-gnm_style_set_format (GnmStyle *style, GOFormat const *format)
+gnm_style_set_format (GnmStyle *style, GOFormat const *fmt)
 {
 	g_return_if_fail (style != NULL);
-	g_return_if_fail (format != NULL);
+	g_return_if_fail (fmt != NULL);
 
 	elem_changed (style, MSTYLE_FORMAT);
-	go_format_ref (format);
+	go_format_ref (fmt);
 	elem_clear_contents (style, MSTYLE_FORMAT);
 	elem_set (style, MSTYLE_FORMAT);
-	style->format = format;
+	style->format = fmt;
 }
 
 /*
  * gnm_style_set_format_text:
- *
  * @style: mstyle to change.
  * @format: An *untranslated* format string.
  */
@@ -1741,6 +1854,12 @@ gnm_style_set_format_text (GnmStyle *style, char const *format)
 	go_format_unref (sf);
 }
 
+/**
+ * gnm_style_get_format:
+ * @style: #GnmStyle to query
+ *
+ * Returns: (transfer none): #GOFormat
+ */
 const GOFormat *
 gnm_style_get_format (GnmStyle const *style)
 {
@@ -1750,6 +1869,11 @@ gnm_style_get_format (GnmStyle const *style)
 	return style->format;
 }
 
+/**
+ * gnm_style_set_align_h:
+ * @style: #GnmStyle to change
+ * @a: A #GnmHAlign
+ **/
 void
 gnm_style_set_align_h (GnmStyle *style, GnmHAlign a)
 {
@@ -1760,6 +1884,12 @@ gnm_style_set_align_h (GnmStyle *style, GnmHAlign a)
 	style->h_align = a;
 }
 
+/**
+ * gnm_style_get_align_h:
+ * @style: #GnmStyle to query
+ *
+ * Returns: A #GnmHAlign
+ **/
 GnmHAlign
 gnm_style_get_align_h (GnmStyle const *style)
 {
@@ -1769,6 +1899,11 @@ gnm_style_get_align_h (GnmStyle const *style)
 	return style->h_align;
 }
 
+/**
+ * gnm_style_set_align_v:
+ * @style: #GnmStyle to change
+ * @a: A #GnmVAlign
+ **/
 void
 gnm_style_set_align_v (GnmStyle *style, GnmVAlign a)
 {
@@ -1779,6 +1914,12 @@ gnm_style_set_align_v (GnmStyle *style, GnmVAlign a)
 	style->v_align = a;
 }
 
+/**
+ * gnm_style_get_align_v:
+ * @style: #GnmStyle to query
+ *
+ * Returns: A #GnmVAlign
+ **/
 GnmVAlign
 gnm_style_get_align_v (GnmStyle const *style)
 {
@@ -1788,6 +1929,11 @@ gnm_style_get_align_v (GnmStyle const *style)
 	return style->v_align;
 }
 
+/**
+ * gnm_style_set_indent:
+ * @style: #GnmStyle to change
+ * @i: Indentation amount
+ **/
 void
 gnm_style_set_indent (GnmStyle *style, int i)
 {
@@ -1798,6 +1944,12 @@ gnm_style_set_indent (GnmStyle *style, int i)
 	style->indent = i;
 }
 
+/**
+ * gnm_style_get_indent:
+ * @style: #GnmStyle to query
+ *
+ * Returns: Indentation amount
+ **/
 int
 gnm_style_get_indent (GnmStyle const *style)
 {
@@ -1807,6 +1959,11 @@ gnm_style_get_indent (GnmStyle const *style)
 	return style->indent;
 }
 
+/**
+ * gnm_style_set_rotation:
+ * @style: #GnmStyle to change
+ * @r: Rotation in degrees relative to horizontal
+ **/
 void
 gnm_style_set_rotation (GnmStyle *style, int rot_deg)
 {
@@ -1817,6 +1974,12 @@ gnm_style_set_rotation (GnmStyle *style, int rot_deg)
 	style->rotation = rot_deg;
 }
 
+/**
+ * gnm_style_get_rotation:
+ * @style: #GnmStyle to query
+ *
+ * Returns: Rotation in degrees relative to horizontal
+ **/
 int
 gnm_style_get_rotation (GnmStyle const *style)
 {
@@ -1826,6 +1989,11 @@ gnm_style_get_rotation (GnmStyle const *style)
 	return style->rotation;
 }
 
+/**
+ * gnm_style_set_text_dir:
+ * @style: #GnmStyle to change
+ * @text_dir: A #GnmTextDir
+ **/
 void
 gnm_style_set_text_dir (GnmStyle *style, GnmTextDir text_dir)
 {
@@ -1836,6 +2004,12 @@ gnm_style_set_text_dir (GnmStyle *style, GnmTextDir text_dir)
 	style->text_dir = text_dir;
 }
 
+/**
+ * gnm_style_get_text_dir:
+ * @style: #GnmStyle to query
+ *
+ * Returns: A #GnmTextDir
+ **/
 GnmTextDir
 gnm_style_get_text_dir (GnmStyle const *style)
 {
@@ -1845,6 +2019,11 @@ gnm_style_get_text_dir (GnmStyle const *style)
 	return style->text_dir;
 }
 
+/**
+ * gnm_style_set_wrap_text:
+ * @style: #GnmStyle to change
+ * @f: %TRUE for wrapping, %FALSE for not
+ **/
 void
 gnm_style_set_wrap_text (GnmStyle *style, gboolean f)
 {
@@ -1855,6 +2034,13 @@ gnm_style_set_wrap_text (GnmStyle *style, gboolean f)
 	style->wrap_text = !!f;
 }
 
+/**
+ * gnm_style_get_wrap_text:
+ * @style: #GnmStyle to query
+ *
+ * Returns: %TRUE for wrapping, %FALSE for not.  See also
+ * gnm_style_get_effective_wrap_text.
+ **/
 gboolean
 gnm_style_get_wrap_text (GnmStyle const *style)
 {
@@ -1863,10 +2049,13 @@ gnm_style_get_wrap_text (GnmStyle const *style)
 	return style->wrap_text;
 }
 
-/*
- * Same as gnm_style_get_wrap_text except that if either halign or valign
- * is _JUSTIFY, the result will be TRUE.
- */
+/**
+ * gnm_style_get_effective_wrap_text:
+ * @style: #GnmStyle to query
+ *
+ * Returns: %TRUE for wrapping, %FALSE for not.  This will be %TRUE also
+ * when either alignment is JUSTIFY.
+ **/
 gboolean
 gnm_style_get_effective_wrap_text (GnmStyle const *style)
 {
@@ -1882,6 +2071,11 @@ gnm_style_get_effective_wrap_text (GnmStyle const *style)
 		style->h_align == GNM_HALIGN_JUSTIFY);
 }
 
+/**
+ * gnm_style_set_shrink_to_fit:
+ * @style: #GnmStyle to change
+ * @f: %TRUE for shrink-to-fit, %FALSE for not
+ **/
 void
 gnm_style_set_shrink_to_fit (GnmStyle *style, gboolean f)
 {
@@ -1892,6 +2086,12 @@ gnm_style_set_shrink_to_fit (GnmStyle *style, gboolean f)
 	style->shrink_to_fit = !!f;
 }
 
+/**
+ * gnm_style_get_shrink_to_fit:
+ * @style: #GnmStyle to query
+ *
+ * Returns: %TRUE for shrink-to-fit, %FALSE for not
+ **/
 gboolean
 gnm_style_get_shrink_to_fit (GnmStyle const *style)
 {
@@ -1901,6 +2101,11 @@ gnm_style_get_shrink_to_fit (GnmStyle const *style)
 	return style->shrink_to_fit;
 }
 
+/**
+ * gnm_style_set_contents_locked:
+ * @style: #GnmStyle to change
+ * @f: %TRUE for locked, %FALSE for not
+ **/
 void
 gnm_style_set_contents_locked (GnmStyle *style, gboolean f)
 {
@@ -1911,6 +2116,12 @@ gnm_style_set_contents_locked (GnmStyle *style, gboolean f)
 	style->contents_locked = !!f;
 }
 
+/**
+ * gnm_style_get_contents_locked:
+ * @style: #GnmStyle to query
+ *
+ * Returns: %TRUE for locked, %FALSE for not
+ **/
 gboolean
 gnm_style_get_contents_locked (GnmStyle const *style)
 {
@@ -1920,6 +2131,11 @@ gnm_style_get_contents_locked (GnmStyle const *style)
 	return style->contents_locked;
 }
 
+/**
+ * gnm_style_set_contents_hidden:
+ * @style: #GnmStyle to change
+ * @f: %TRUE for hidden, %FALSE for not
+ **/
 void
 gnm_style_set_contents_hidden (GnmStyle *style, gboolean f)
 {
@@ -1930,6 +2146,12 @@ gnm_style_set_contents_hidden (GnmStyle *style, gboolean f)
 	style->contents_hidden = !!f;
 }
 
+/**
+ * gnm_style_get_contents_hidden:
+ * @style: #GnmStyle to query
+ *
+ * Return: %TRUE for hidden, %FALSE for not
+ **/
 gboolean
 gnm_style_get_contents_hidden (GnmStyle const *style)
 {
@@ -1941,7 +2163,7 @@ gnm_style_get_contents_hidden (GnmStyle const *style)
 
 /**
  * gnm_style_set_validation:
- * @style: #GnmStyle
+ * @style: #GnmStyle to change
  * @v: (transfer full): #GnmValidation
  **/
 void
@@ -1957,7 +2179,7 @@ gnm_style_set_validation (GnmStyle *style, GnmValidation *v)
 
 /**
  * gnm_style_get_validation:
- * @style: #GnmStyle
+ * @style: #GnmStyle to query
  *
  * Returns: (transfer none):
  **/
@@ -1972,8 +2194,8 @@ gnm_style_get_validation (GnmStyle const *style)
 
 /**
  * gnm_style_set_hlink:
- * @style: #GnmStyle
- * @lnk: (transfer full): #GnmHLink
+ * @style: #GnmStyle to change
+ * @lnk: (transfer full) (nullable): #GnmHLink
  *
  * This sets a link for @style.
  **/
@@ -1990,9 +2212,9 @@ gnm_style_set_hlink (GnmStyle *style, GnmHLink *lnk)
 
 /**
  * gnm_style_get_hlink:
- * @style: #GnmStyle
+ * @style: #GnmStyle to query
  *
- * Returns: (transfer none): the associated #GnmHLink.
+ * Returns: (transfer none) (nullable): the associated #GnmHLink.
  **/
 GnmHLink *
 gnm_style_get_hlink (GnmStyle const *style)
@@ -2005,8 +2227,8 @@ gnm_style_get_hlink (GnmStyle const *style)
 
 /**
  * gnm_style_set_input_msg:
- * @style: #GnmStyle
- * @msg: (transfer full): #GnmInputMsg
+ * @style: #GnmStyle to change
+ * @msg: (transfer full) (nullable): #GnmInputMsg
  *
  * This sets an input message for @style.
  **/
@@ -2023,10 +2245,9 @@ gnm_style_set_input_msg (GnmStyle *style, GnmInputMsg *msg)
 
 /**
  * gnm_style_get_input_msg:
- * @style: #GnmStyle
+ * @style: #GnmStyle to query
  *
- * Returns: (transfer none): the currently set input message assuming
- * that the style has such.
+ * Returns: (transfer none) (nullable): the currently set input message.
  **/
 GnmInputMsg *
 gnm_style_get_input_msg (GnmStyle const *style)
@@ -2039,7 +2260,7 @@ gnm_style_get_input_msg (GnmStyle const *style)
 
 /**
  * gnm_style_set_conditions:
- * @style: #GnmStyle
+ * @style: #GnmStyle to change
  * @sc: (transfer full): #GnmStyleConditions
  *
  * This sets conditional style for @style.
@@ -2057,10 +2278,9 @@ gnm_style_set_conditions (GnmStyle *style, GnmStyleConditions *sc)
 
 /**
  * gnm_style_get_conditions:
- * @style: #GnmStyle
+ * @style: #GnmStyle to query
  *
- * Returns: (transfer none): the currently set conditional style assuming
- * that the style has such.
+ * Returns: (transfer none) (nullable): the currently set conditional style.
  **/
 GnmStyleConditions *
 gnm_style_get_conditions (GnmStyle const *style)
@@ -2072,7 +2292,7 @@ gnm_style_get_conditions (GnmStyle const *style)
 
 /**
  * gnm_style_get_cond_style:
- * @style: #GnmStyle
+ * @style: #GnmStyle to query
  * @ix: The index of the condition for which style is desired
  *
  * Returns: (transfer none): the resulting style from applying the condition's
@@ -2083,15 +2303,16 @@ gnm_style_get_cond_style (GnmStyle const *style, int ix)
 {
 	g_return_val_if_fail (style != NULL, NULL);
 	g_return_val_if_fail (elem_is_set (style, MSTYLE_CONDITIONS), NULL);
-	g_return_val_if_fail (style->cond_styles != NULL, NULL);
+	g_return_val_if_fail (style->conditions != NULL, NULL);
+	g_return_val_if_fail (ix >= 0 && (unsigned)ix < gnm_style_conditions_details (style->conditions)->len, NULL);
 
-	g_return_val_if_fail (ix >= 0 && (unsigned)ix < style->cond_styles->len, NULL);
+	if (style->changed)
+		gnm_style_update ((GnmStyle *)style);
 
 	return g_ptr_array_index (style->cond_styles, ix);
 }
 
 
-
 static gboolean
 debug_style_deps (void)
 {
@@ -2242,9 +2463,13 @@ add_attr (PangoAttrList *attrs, PangoAttribute *attr)
 }
 
 /**
- * gnm_style_get_pango_attrs:
- * @style: #GnmStyle
- **/
+ * gnm_style_generate_attrs:
+ * @style: style to query
+ *
+ * Returns: (transfer full): a #PangoAttrList with attributes matching
+ * @style.  Attributes where the default will serve are not included.
+ * The foreground color is not included.
+ */
 PangoAttrList *
 gnm_style_get_pango_attrs (GnmStyle const *style,
 			   PangoContext *context,
@@ -2305,6 +2530,13 @@ gnm_style_get_pango_attrs (GnmStyle const *style,
 	return l;
 }
 
+/**
+ * gnm_style_generate_attrs_full:
+ * @style: style to query
+ *
+ * Returns: (transfer full): a #PangoAttrList with attributes matching
+ * @style, even attributes where the default would have served.
+ */
 PangoAttrList *
 gnm_style_generate_attrs_full (GnmStyle const *style)
 {
