@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * parse-util.c: Various utility routines to parse or produce
  *     string representations of common reference types.
@@ -22,25 +21,25 @@
  * USA
  */
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "parse-util.h"
+#include <gnumeric.h>
+#include <parse-util.h>
 
-#include "application.h"
-#include "workbook.h"
-#include "sheet.h"
-#include "value.h"
-#include "ranges.h"
-#include "cell.h"
-#include "expr.h"
-#include "number-match.h"
-#include "gnm-format.h"
-#include "expr-name.h"
-#include "func.h"
-#include "mstyle.h"
-#include "sheet-style.h"
+#include <application.h>
+#include <workbook.h>
+#include <sheet.h>
+#include <value.h>
+#include <ranges.h>
+#include <cell.h>
+#include <expr.h>
+#include <number-match.h>
+#include <gnm-format.h>
+#include <expr-name.h>
+#include <func.h>
+#include <mstyle.h>
+#include <sheet-style.h>
 /* For std_expr_name_handler: */
-#include "expr-impl.h"
-#include "gutils.h"
+#include <expr-impl.h>
+#include <gutils.h>
 #include <goffice/goffice.h>
 
 #include <errno.h>
@@ -728,7 +727,7 @@ cell_name (GnmCell const *cell)
  * @cell_str:   a string representation of a cell name.
  * @ss:          #GnmSheetSize
  * @res:         result
- * @strict:      if this is TRUE, then parsing stops at possible errors,
+ * @strict:      if this is %TRUE, then parsing stops at possible errors,
  *               otherwise an attempt is made to return cell names with
  *               trailing garbage.
  *
@@ -955,7 +954,7 @@ unquote (char *dst, char const *src, int n)
  * @start:
  * @wb:
  *
- * Returns : NULL if there is a valid workbook name but it is unknown.
+ * Returns: %NULL if there is a valid workbook name but it is unknown.
  *           If the string is a valid workbook known name it returns a pointer
  *           the end of the name.
  *           Otherwise returns @start and does not modify @wb.
