@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * position.c: Utility routines for various types of positional
  *         coordinates.
@@ -22,17 +21,17 @@
  * USA
  */
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "libgnumeric.h"
-#include "position.h"
+#include <gnumeric.h>
+#include <libgnumeric.h>
+#include <position.h>
 
-#include "sheet.h"
-#include "sheet-view.h"
-#include "cell.h"
-#include "value.h"
-#include "ranges.h"
+#include <sheet.h>
+#include <sheet-view.h>
+#include <cell.h>
+#include <value.h>
+#include <ranges.h>
 #include <string.h>
-#include "workbook.h"
+#include <workbook.h>
 
 /* GnmCellPos made a boxed type */
 static GnmCellPos *
@@ -60,9 +59,7 @@ gnm_cell_pos_get_type (void)
 static GnmEvalPos *
 gnm_eval_pos_dup (GnmEvalPos *ep)
 {
-	GnmEvalPos *res = g_new0 (GnmEvalPos, 1);
-	memcpy (res, ep, sizeof (GnmEvalPos)); /* is this safe? */
-	return res;
+	return g_memdup (ep, sizeof (*ep));
 }
 
 GType
@@ -85,7 +82,7 @@ gnm_eval_pos_get_type (void)
  * @col: column.
  * @row: row
  *
- * Returns: (transfer none): the initialized #GnmEvalPos (@ep).
+ * Returns: (skip) (transfer none): the initialized #GnmEvalPos (@ep).
  **/
 GnmEvalPos *
 eval_pos_init (GnmEvalPos *ep, Sheet *sheet, int col, int row)
@@ -108,7 +105,7 @@ eval_pos_init (GnmEvalPos *ep, Sheet *sheet, int col, int row)
  * @s: #Sheet
  * @pos: #GnmCellPos
  *
- * Returns: (transfer none): the initialized #GnmEvalPos (@ep).
+ * Returns: (skip) (transfer none): the initialized #GnmEvalPos (@ep).
  **/
 GnmEvalPos *
 eval_pos_init_pos (GnmEvalPos *ep, Sheet *sheet, GnmCellPos const *pos)
@@ -130,7 +127,7 @@ eval_pos_init_pos (GnmEvalPos *ep, Sheet *sheet, GnmCellPos const *pos)
  * @ep: The position to init.
  * @dep:
  *
- * Returns: (transfer none): the initialized #GnmEvalPos (@ep).
+ * Returns: (skip) (transfer none): the initialized #GnmEvalPos (@ep).
  **/
 GnmEvalPos *
 eval_pos_init_dep (GnmEvalPos *ep, GnmDependent const *dep)
@@ -153,7 +150,7 @@ eval_pos_init_dep (GnmEvalPos *ep, GnmDependent const *dep)
  *
  * The function initializes an evalpos with the edit position from the
  * given sheetview.
- * Returns: (transfer none): the initialized #GnmEvalPos (@ep).
+ * Returns: (skip) (transfer none): the initialized #GnmEvalPos (@ep).
  **/
 GnmEvalPos *
 eval_pos_init_editpos (GnmEvalPos *ep, SheetView const *sv)
@@ -172,7 +169,7 @@ eval_pos_init_editpos (GnmEvalPos *ep, SheetView const *sv)
  *
  * The function initializes an evalpos with the given cell
  *
- * Returns: (transfer none): the initialized #GnmEvalPos (@ep).
+ * Returns: (skip) (transfer none): the initialized #GnmEvalPos (@ep).
  */
 GnmEvalPos *
 eval_pos_init_cell (GnmEvalPos *ep, GnmCell const *cell)
@@ -195,7 +192,7 @@ eval_pos_init_cell (GnmEvalPos *ep, GnmCell const *cell)
  *
  * The function initializes an evalpos with the given sheet.
  *
- * Returns: (transfer none): the initialized #GnmEvalPos (@ep).
+ * Returns: (skip) (transfer none): the initialized #GnmEvalPos (@ep).
  */
 GnmEvalPos *
 eval_pos_init_sheet (GnmEvalPos *ep, Sheet const *sheet)
@@ -219,11 +216,9 @@ eval_pos_is_array_context (GnmEvalPos const *ep)
 
 
 static GnmParsePos *
-gnm_parse_pos_dup (GnmParsePos *ep)
+gnm_parse_pos_dup (GnmParsePos *pp)
 {
-	GnmParsePos *res = g_new0 (GnmParsePos, 1);
-	memcpy (res, ep, sizeof (GnmParsePos)); /* is this safe? */
-	return res;
+	return g_memdup (pp, sizeof (*pp));
 }
 
 GType
@@ -239,9 +234,8 @@ gnm_parse_pos_get_type (void)
 	return t;
 }
 
-/*
+/**
  * parse_pos_init:
- *
  * @pp: The position to init.
  * @sheet: The sheet being selected
  * @wb: The workbook being selected.
@@ -250,7 +244,7 @@ gnm_parse_pos_get_type (void)
  *
  * Use either a sheet (preferred) or a workbook to initialize the supplied
  * ParsePosition.
- * Returns: (transfer none): the initialized #GnmParsePos (@pp).
+ * Returns: (skip) (transfer none): the initialized #GnmParsePos (@pp).
  */
 GnmParsePos *
 parse_pos_init (GnmParsePos *pp, Workbook *wb, Sheet const *sheet,
@@ -270,12 +264,12 @@ parse_pos_init (GnmParsePos *pp, Workbook *wb, Sheet const *sheet,
 	return pp;
 }
 
-/*
+/**
  * parse_pos_init_dep:
  * @pp: The position to init.
  * @dep: The dependent
  *
- * Returns: (transfer none): the initialized #GnmParsePos (@pp).
+ * Returns: (skip) (transfer none): the initialized #GnmParsePos (@pp).
  */
 GnmParsePos *
 parse_pos_init_dep (GnmParsePos *pp, GnmDependent const *dep)
@@ -289,12 +283,12 @@ parse_pos_init_dep (GnmParsePos *pp, GnmDependent const *dep)
 	return pp;
 }
 
-/*
+/**
  * parse_pos_init_cell:
  * @pp: The position to init.
  * @cell: The cell
  *
- * Returns: (transfer none): the initialized #GnmParsePos (@pp).
+ * Returns: (skip) (transfer none): the initialized #GnmParsePos (@pp).
  */
 GnmParsePos *
 parse_pos_init_cell (GnmParsePos *pp, GnmCell const *cell)
@@ -307,12 +301,12 @@ parse_pos_init_cell (GnmParsePos *pp, GnmCell const *cell)
 			       cell->pos.col, cell->pos.row);
 }
 
-/*
+/**
  * parse_pos_init_evalpos:
  * @pp: The position to init.
- * @ep: #GnmEvalPos
+ * @pos: #GnmEvalPos
  *
- * Returns: (transfer none): the initialized #GnmParsePos (@pp).
+ * Returns: (skip) (transfer none): the initialized #GnmParsePos (@pp).
  */
 GnmParsePos *
 parse_pos_init_evalpos (GnmParsePos *pp, GnmEvalPos const *ep)
@@ -322,12 +316,12 @@ parse_pos_init_evalpos (GnmParsePos *pp, GnmEvalPos const *ep)
 	return parse_pos_init (pp, NULL, ep->sheet, ep->eval.col, ep->eval.row);
 }
 
-/*
+/**
  * parse_pos_init_editpos:
  * @pp: The position to init.
  * @sv: sheet view
  *
- * Returns: (transfer none): the initialized #GnmParsePos (@pp).
+ * Returns: (skip) (transfer none): the initialized #GnmParsePos (@pp).
  */
 GnmParsePos *
 parse_pos_init_editpos (GnmParsePos *pp, SheetView const *sv)
@@ -338,12 +332,12 @@ parse_pos_init_editpos (GnmParsePos *pp, SheetView const *sv)
 		sv->edit_pos.col, sv->edit_pos.row);
 }
 
-/*
+/**
  * parse_pos_init_sheet:
  * @pp: The position to init.
  * @sheet: The sheet
  *
- * Returns: (transfer none): the initialized #GnmParsePos (@pp).
+ * Returns: (skip) (transfer none): the initialized #GnmParsePos (@pp).
  */
 GnmParsePos *
 parse_pos_init_sheet (GnmParsePos *pp, Sheet const *sheet)
@@ -357,11 +351,9 @@ parse_pos_init_sheet (GnmParsePos *pp, Sheet const *sheet)
 
 
 static GnmCellRef *
-gnm_cellref_dup (GnmCellRef *ep)
+gnm_cellref_dup (GnmCellRef *cr)
 {
-	GnmCellRef *res = g_new0 (GnmCellRef, 1);
-	memcpy (res, ep, sizeof (GnmCellRef)); /* is this safe? */
-	return res;
+	return g_memdup (cr, sizeof (*cr));
 }
 
 GType
@@ -620,4 +612,3 @@ gnm_cellpos_equal (GnmCellPos const *a, GnmCellPos const *b)
 {
 	return (a->row == b->row && a->col == b->col);
 }
-
