@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * rangefunc.c: Functions on ranges (data sets).
  *
@@ -8,14 +7,17 @@
  */
 
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "rangefunc.h"
+#include <gnumeric.h>
+#include <rangefunc.h>
 
-#include "mathfunc.h"
+#include <mathfunc.h>
+#include <sf-gamma.h>
+#include <gutils.h>
 #include <math.h>
 #include <stdlib.h>
 #include <string.h>
-#include "tools/analysis-tools.h"
+#include <tools/analysis-tools.h>
+
 int
 gnm_range_count (G_GNUC_UNUSED gnm_float const *xs, int n, gnm_float *res)
 {
@@ -380,14 +382,21 @@ gnm_range_covar_est (gnm_float const *xs, const gnm_float *ys, int n, gnm_float
 int
 gnm_range_correl_pop (gnm_float const *xs, const gnm_float *ys, int n, gnm_float *res)
 {
-	gnm_float sx, sy, vxy;
+	gnm_float sx, sy, vxy, c;
 
 	if (gnm_range_stddev_pop (xs, n, &sx) || sx == 0 ||
 	    gnm_range_stddev_pop (ys, n, &sy) || sy == 0 ||
 	    gnm_range_covar_pop (xs, ys, n, &vxy))
 		return 1;
 
-	*res = vxy / (sx * sy);
+	c = vxy / (sx * sy);
+
+	// Rounding errors can push us beyond [-1,+1].  Avoid that.
+	// This isn't a great solution, but it'll have to do until
+	// someone comes up with a better approach.
+	c = CLAMP (c, -1.0, +1.0);
+
+	*res = c;
 	return 0;
 }
 
