@@ -1,8 +1,7 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_REGRESSION_H_
 # define _GNM_REGRESSION_H_
 
-#include "numbers.h"
+#include <numbers.h>
 #include <goffice/goffice.h>
 
 G_BEGIN_DECLS
@@ -21,8 +20,6 @@ G_BEGIN_DECLS
 #	define gnm_matrix_invert go_matrix_invertl
 #	define gnm_matrix_pseudo_inverse go_matrix_pseudo_inversel
 #	define gnm_matrix_determinant go_matrix_determinantl
-#	define gnm_linear_solve go_linear_solvel
-#	define gnm_linear_solve_multiple go_linear_solve_multiplel
 #else
 #	define gnm_regression_stat_t go_regression_stat_t
 #	define gnm_regression_stat_new go_regression_stat_new
@@ -37,8 +34,6 @@ G_BEGIN_DECLS
 #	define gnm_matrix_invert go_matrix_invert
 #	define gnm_matrix_pseudo_inverse go_matrix_pseudo_inverse
 #	define gnm_matrix_determinant go_matrix_determinant
-#	define gnm_linear_solve go_linear_solve
-#	define gnm_linear_solve_multiple go_linear_solve_multiple
 #endif
 
 G_END_DECLS
