@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * sheet-autofill.c: Provides the autofill features
  *
@@ -9,20 +8,20 @@
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "gnumeric.h"
-#include "sheet-autofill.h"
+#include <gnumeric.h>
+#include <sheet-autofill.h>
 
-#include "sheet.h"
-#include "cell.h"
-#include "value.h"
-#include "workbook.h"
-#include "sheet-style.h"
-#include "expr.h"
-#include "gnm-datetime.h"
-#include "mstyle.h"
-#include "ranges.h"
-#include "sheet-merge.h"
-#include "gnm-format.h"
+#include <sheet.h>
+#include <cell.h>
+#include <value.h>
+#include <workbook.h>
+#include <sheet-style.h>
+#include <expr.h>
+#include <gnm-datetime.h>
+#include <mstyle.h>
+#include <ranges.h>
+#include <sheet-merge.h>
+#include <gnm-format.h>
 #include <goffice/goffice.h>
 
 #include <string.h>
@@ -38,6 +37,9 @@ static char *weekday_names_short[7 + 1];
 static char *quarters[4 + 1];
 static gboolean has_quarters;
 
+/**
+ * gnm_autofill_init: (skip)
+ */
 void
 gnm_autofill_init (void)
 {
@@ -67,6 +69,9 @@ gnm_autofill_init (void)
 	}
 }
 
+/**
+ * gnm_autofill_shutdown: (skip)
+ */
 void
 gnm_autofill_shutdown (void)
 {
@@ -259,8 +264,7 @@ as_finalize (ArithString *as)
 		g_string_free (as->suffix, TRUE);
 }
 
-static
-gboolean
+static gboolean
 as_check_prefix_suffix (ArithString *as, char const *s, gsize slen)
 {
 	if (as->prefix) {
