@@ -1,8 +1,7 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_SHEET_CONTROL_PRIV_H_
 # define _GNM_SHEET_CONTROL_PRIV_H_
 
-#include "sheet-control.h"
+#include <sheet-control.h>
 
 G_BEGIN_DECLS
 
