@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * sheet-object-image.c: a wrapper for gdkpixbuf to display images.
@@ -7,25 +6,24 @@
  *	Jody Goldberg (jody@gnome.org)
  */
 #include <gnumeric-config.h>
-#include "gnm-i18n.h"
-#include "gnumeric.h"
-#include "sheet-object-image.h"
-#include "sheet.h"
+#include <gnm-i18n.h>
+#include <gnumeric.h>
+#include <sheet-object-image.h>
+#include <sheet.h>
 
-#include "gnm-pane.h"
-#include "wbc-gtk.h"
-#include "sheet-object-impl.h"
-#include "sheet-control-gui.h"
-#include "gui-file.h"
-#include "application.h"
-#include "gutils.h"
-#include "xml-sax.h"
+#include <gnm-pane.h>
+#include <wbc-gtk.h>
+#include <sheet-object-impl.h>
+#include <sheet-control-gui.h>
+#include <gui-file.h>
+#include <application.h>
+#include <gutils.h>
+#include <xml-sax.h>
 
 #include <goffice/goffice.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-output-stdio.h>
 #include <gsf/gsf-utils.h>
-#include <gtk/gtk.h>
 
 #include <math.h>
 #include <string.h>
@@ -345,7 +343,7 @@ gnm_soi_populate_menu (SheetObject *so, GPtrArray *actions)
 	static SheetObjectAction const soi_action =
 		{ "document-save-as", N_("_Save As Image"), NULL, 0, soi_cb_save_as };
 	gnm_soi_parent_class->populate_menu (so, actions);
-	go_ptr_array_insert (actions, (gpointer) &soi_action, 1);
+	g_ptr_array_insert (actions, 1, (gpointer) &soi_action);
 }
 
 static void
