@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * sheet-style.c: storage mechanism for styles and eventually cells.
  *
@@ -22,17 +21,17 @@
  */
 
 #include <gnumeric-config.h>
-#include "sheet-style.h"
-#include "ranges.h"
-#include "sheet.h"
-#include "expr.h"
-#include "style.h"
-#include "style-border.h"
-#include "style-color.h"
-#include "style-conditions.h"
-#include "parse-util.h"
-#include "cell.h"
-#include "gutils.h"
+#include <sheet-style.h>
+#include <ranges.h>
+#include <sheet.h>
+#include <expr.h>
+#include <style.h>
+#include <style-border.h>
+#include <style-color.h>
+#include <style-conditions.h>
+#include <parse-util.h>
+#include <cell.h>
+#include <gutils.h>
 #include <goffice/goffice.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
@@ -183,10 +182,9 @@ sheet_style_unlink (Sheet *sheet, GnmStyle *st)
 /**
  * sheet_style_find:
  * @sheet: (transfer full): the sheet
- * @st: a style
+ * @st: (transfer full): a style
  *
  * Looks up a style from the sheets collection.  Linking if necessary.
- * ABSORBS the reference and adds a link.
  *
  * Returns: (transfer full): the new style.
  */
@@ -825,7 +823,6 @@ sheet_style_shutdown (Sheet *sheet)
  * @grid_color: (transfer full): The color
  *
  * Set the color for rendering auto colored patterns in this sheet.
- * Absorbs a reference to @pattern_color;
  **/
 void
 sheet_style_set_auto_pattern_color (Sheet *sheet, GnmColor *pattern_color)
@@ -1346,12 +1343,11 @@ tail_recursion:
 
 /**
  * sheet_style_set_range:
- * @sheet:
- * @range:
- * @style: #GnmStyle
+ * @sheet: #Sheet being changed
+ * @range: #GnmRange being changed
+ * @style: (transfer full): New #GnmStyle
  *
  * Change the complete style for a region.
- * This function absorbs a reference to the new @style.
  */
 void
 sheet_style_set_range (Sheet *sheet, GnmRange const *range,
@@ -1381,15 +1377,14 @@ sheet_style_set_range (Sheet *sheet, GnmRange const *range,
 
 /**
  * sheet_style_apply_col:
- * @sheet:
- * @col:
- * @style: #GnmStyle
+ * @sheet: #Sheet being changed
+ * @col: Column
+ * @style: (transfer full): #GnmStyle
  *
  * NOTE: This is a simple wrapper for now.  When we support col/row styles it
  *	will make life easier.
  *
  * Apply a partial style to a full col.
- * The routine absorbs a reference to the partial style.
  **/
 void
 sheet_style_apply_col (Sheet *sheet, int col, GnmStyle *pstyle)
@@ -1403,13 +1398,12 @@ sheet_style_apply_col (Sheet *sheet, int col, GnmStyle *pstyle)
  * sheet_style_apply_row:
  * @sheet:
  * @row:
- * @style: #GnmStyle
+ * @style: (transfer full): #GnmStyle
  *
  * NOTE: This is a simple wrapper for now.  When we support col/row styles it
  *	will make life easier.
  *
  * Apply a partial style to a full col.
- * The routine absorbs a reference to the partial style.
  **/
 void
 sheet_style_apply_row (Sheet  *sheet, int row, GnmStyle *pstyle)
@@ -1424,14 +1418,12 @@ sheet_style_apply_row (Sheet  *sheet, int row, GnmStyle *pstyle)
  * @sheet:
  * @col:
  * @row:
- * @style: #GnmStyle
+ * @style: (transfer full): #GnmStyle
  *
  * Apply a partial style to a single cell
- * This function absorbs a reference to the new @style.
  **/
 void
-sheet_style_apply_pos (Sheet *sheet, int col, int row,
-		       GnmStyle *pstyle)
+sheet_style_apply_pos (Sheet *sheet, int col, int row, GnmStyle *pstyle)
 {
 	ReplacementStyle rs;
 
@@ -1448,10 +1440,9 @@ sheet_style_apply_pos (Sheet *sheet, int col, int row,
  * @sheet:
  * @col:
  * @row:
- * @style:
+ * @style: (transfer full):
  *
  * Change the complete style for a single cell.
- * This function absorbs a reference to the new @style.
  **/
 void
 sheet_style_set_pos (Sheet *sheet, int col, int row,
@@ -1755,7 +1746,6 @@ style_row_init (GnmBorder const * * *prev_vert,
  * @pstyle: (transfer full): A partial style to apply
  *
  * Apply a partial style to a region.
- * The routine absorbs a reference to the partial style.
  */
 void
 sheet_style_apply_range (Sheet *sheet, GnmRange const *range, GnmStyle *pstyle)
@@ -1786,7 +1776,7 @@ sheet_style_apply_range (Sheet *sheet, GnmRange const *range, GnmStyle *pstyle)
  * sheet_style_apply_range2: (skip)
  * @sheet: #Sheet
  * @range: #GnmRange to apply over
- * @pstyle: A partial style to apply
+ * @pstyle: (transfer none): A partial style to apply
  *
  * Apply a partial style to a region.
  */
@@ -1964,11 +1954,13 @@ cb_find_conflicts (GnmStyle *style,
 }
 
 static void
-border_mask_internal (gboolean *known, GnmBorder **borders,
+border_mask_internal (gboolean known[GNM_STYLE_BORDER_EDGE_MAX],
+		      GnmBorder *borders[GNM_STYLE_BORDER_EDGE_MAX],
 		      GnmBorder const *b, GnmStyleBorderLocation l)
 {
 	if (!known[l]) {
 		known[l] = TRUE;
+		gnm_style_border_unref (borders[l]);
 		borders[l] = (GnmBorder *)b;
 		gnm_style_border_ref (borders[l]);
 	} else if (borders[l] != b && borders[l] != NULL) {
@@ -1978,7 +1970,8 @@ border_mask_internal (gboolean *known, GnmBorder **borders,
 }
 
 static void
-border_mask (gboolean *known, GnmBorder **borders,
+border_mask (gboolean known[GNM_STYLE_BORDER_EDGE_MAX],
+	     GnmBorder *borders[GNM_STYLE_BORDER_EDGE_MAX],
 	     GnmBorder const *b, GnmStyleBorderLocation l)
 {
 	if (b == NULL)
@@ -1987,7 +1980,8 @@ border_mask (gboolean *known, GnmBorder **borders,
 }
 
 static void
-border_mask_vec (gboolean *known, GnmBorder **borders,
+border_mask_vec (gboolean known[GNM_STYLE_BORDER_EDGE_MAX],
+		 GnmBorder *borders[GNM_STYLE_BORDER_EDGE_MAX],
 		 GnmBorder const * const *vec, int first, int last,
 		 GnmStyleBorderLocation l)
 {
@@ -2009,17 +2003,18 @@ border_mask_vec (gboolean *known, GnmBorder **borders,
 }
 
 /**
- * sheet_style_get_uniform:
- * @sheet:
- * @range:
- * @borders:
+ * sheet_style_find_conflicts:
+ * @sheet: #Sheet to query
+ * @r: #GnmRange to query
+ * @style: (inout):
+ * @borders: (out) (array fixed-size=8):
  *
- * Find out what style elements are common to every cell in a range
- * Returns a flag of TRUE if there was a conflict a given style element
+ * Returns: bitmask of conflicts
  */
 unsigned int
 sheet_style_find_conflicts (Sheet const *sheet, GnmRange const *r,
-			    GnmStyle **style, GnmBorder **borders)
+			    GnmStyle **style,
+			    GnmBorder *borders[GNM_STYLE_BORDER_EDGE_MAX])
 {
 	int n, col, row, start_col, end_col;
 	GnmStyleRow sr;
@@ -2043,8 +2038,10 @@ sheet_style_find_conflicts (Sheet const *sheet, GnmRange const *r,
 			borders[i] = gnm_style_border_ref ((GnmBorder *)none);
 		}
 	} else {
-		for (i = GNM_STYLE_BORDER_TOP ; i < GNM_STYLE_BORDER_EDGE_MAX ; i++)
+		for (i = GNM_STYLE_BORDER_TOP ; i < GNM_STYLE_BORDER_EDGE_MAX ; i++) {
 			known[i] = TRUE;
+			borders[i] = NULL;
+		}
 	}
 
 	user.accum = *style;
@@ -2054,6 +2051,7 @@ sheet_style_find_conflicts (Sheet const *sheet, GnmRange const *r,
 	/* copy over the diagonals */
 	for (i = GNM_STYLE_BORDER_REV_DIAG ; i <= GNM_STYLE_BORDER_DIAG ; i++) {
 		GnmStyleElement se = GNM_STYLE_BORDER_LOCATION_TO_STYLE_ELEMENT (i);
+		gnm_style_border_unref (borders[i]);
 		if (user.conflicts & (1 << se))
 			borders[i] = NULL;
 		else
