@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * border.c: Managing drawing and printing cell borders
@@ -21,13 +20,13 @@
  * USA
  */
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "style-border.h"
+#include <gnumeric.h>
+#include <style-border.h>
 
-#include "style-color.h"
-#include "style.h"
-#include "sheet-style.h"
-#include "sheet.h"
+#include <style-color.h>
+#include <style.h>
+#include <sheet-style.h>
+#include <sheet.h>
 #include <gdk/gdk.h>
 #include <string.h>
 
@@ -136,6 +135,11 @@ style_border_hash (gconstpointer v)
 	return (GPOINTER_TO_UINT(b->color) ^ b->line_type);
 }
 
+/**
+ * gnm_style_border_none:
+ *
+ * Returns: (transfer none): A #GnmBorder with no borders.
+ */
 GnmBorder *
 gnm_style_border_none (void)
 {
@@ -155,7 +159,7 @@ gnm_style_border_none (void)
 
 /**
  * gnm_style_border_none_set_color:
- * @color:
+ * @color: (transfer full): #GnmColor
  *
  * This function updates the color of gnm_style_border_none when the wanted grid
  * color is known. gnm_style_border_none tells how to render the grid. Because
@@ -165,7 +169,6 @@ gnm_style_border_none (void)
  * color is default (which is black), the grid color is gray, as returned by
  * style_color_grid ().  - otherwise, the auto pattern color is used for the
  * grid.
- * NOTE : Absorbs a reference to @color.
  */
 void
 gnm_style_border_none_set_color (GnmColor *color)
@@ -186,12 +189,10 @@ gnm_style_border_none_set_color (GnmColor *color)
 /**
  * gnm_style_border_fetch:
  * @line_type: dash style
- * @color: (transfer full): colour
+ * @color: (transfer full) (nullable): colour
  * @orientation: Not currently used.
  *
- * Fetches a GnmBorder from the cache, creating one if necessary.  Absorbs
- * the colour reference.  In the future we may have different dash styles for
- * the same pattern depending on whether this is a horizontal or vertical line.
+ * Returns: (transfer full): A #GnmBorder
  */
 GnmBorder *
 gnm_style_border_fetch (GnmStyleBorderType		 line_type,
@@ -207,8 +208,7 @@ gnm_style_border_fetch (GnmStyleBorderType		 line_type,
 	}
 
 	if (line_type == GNM_STYLE_BORDER_NONE) {
-		if (color)
-			style_color_unref (color);
+		style_color_unref (color);
 		return gnm_style_border_ref (gnm_style_border_none ());
 	}
 
@@ -220,8 +220,7 @@ gnm_style_border_fetch (GnmStyleBorderType		 line_type,
 	if (border_hash) {
 		border = g_hash_table_lookup (border_hash, &key);
 		if (border != NULL) {
-			if (color)
-				style_color_unref (color);
+			style_color_unref (color);
 			return gnm_style_border_ref (border);
 		}
 	} else
@@ -280,6 +279,12 @@ gnm_style_border_get_orientation (GnmStyleBorderLocation type)
 	}
 }
 
+/**
+ * gnm_style_border_ref:
+ * @border: (nullable): #GnmBorder
+ *
+ * Returns: (transfer full): a reference to @border
+ */
 GnmBorder *
 gnm_style_border_ref (GnmBorder *border)
 {
@@ -291,6 +296,10 @@ gnm_style_border_ref (GnmBorder *border)
 	return border;
 }
 
+/**
+ * gnm_style_border_unref:
+ * @border: (transfer full) (nullable): #GnmBorder
+ */
 void
 gnm_style_border_unref (GnmBorder *border)
 {
@@ -314,10 +323,8 @@ gnm_style_border_unref (GnmBorder *border)
 	/* Remove here, before we mess with the hashed fields.  */
 	g_hash_table_remove (border_hash, border);
 
-	if (border->color) {
-		style_color_unref (border->color);
-		border->color = NULL;
-	}
+	style_color_unref (border->color);
+	border->color = NULL;
 
 	g_free (border);
 }
@@ -334,12 +341,19 @@ cb_border_leak (gpointer key, gpointer value, gpointer user_data)
 		    border->ref_count);
 }
 
+/**
+ * gnm_border_shutdown: (skip)
+ */
 void
 gnm_border_shutdown (void)
 {
 	if (border_none) {
-		style_color_unref (border_none->color);
-		g_free (border_none);
+		if (border_none->ref_count == 1) {
+			style_color_unref (border_none->color);
+			g_free (border_none);
+		} else {
+			cb_border_leak (NULL, border_none, NULL);
+		}
 		border_none = NULL;
 	}
 
