@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * color.c: Color allocation on the Gnumeric spreadsheet
  *
@@ -7,10 +6,9 @@
  *
  */
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "style-color.h"
-#include "style-border.h"
-#include <gtk/gtk.h>
+#include <gnumeric.h>
+#include <style-color.h>
+#include <style-border.h>
 
 static GHashTable *style_color_hash;
 static GnmColor *sc_black;
@@ -242,35 +240,23 @@ cb_color_leak (gpointer key, gpointer value, gpointer user_data)
 void
 gnm_color_shutdown (void)
 {
-	if (sc_black) {
-		style_color_unref (sc_black);
-		sc_black = NULL;
-	}
+	style_color_unref (sc_black);
+	sc_black = NULL;
 
-	if (sc_white) {
-		style_color_unref (sc_white);
-		sc_white = NULL;
-	}
+	style_color_unref (sc_white);
+	sc_white = NULL;
 
-	if (sc_grid) {
-		style_color_unref (sc_grid);
-		sc_grid = NULL;
-	}
+	style_color_unref (sc_grid);
+	sc_grid = NULL;
 
-	if (sc_auto_back) {
-		style_color_unref (sc_auto_back);
-		sc_auto_back = NULL;
-	}
+	style_color_unref (sc_auto_back);
+	sc_auto_back = NULL;
 
-	if (sc_auto_font) {
-		style_color_unref (sc_auto_font);
-		sc_auto_font = NULL;
-	}
+	style_color_unref (sc_auto_font);
+	sc_auto_font = NULL;
 
-	if (sc_auto_pattern) {
-		style_color_unref (sc_auto_pattern);
-		sc_auto_pattern = NULL;
-	}
+	style_color_unref (sc_auto_pattern);
+	sc_auto_pattern = NULL;
 
 	g_hash_table_foreach (style_color_hash, cb_color_leak, NULL);
 	g_hash_table_destroy (style_color_hash);
