@@ -1,8 +1,7 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_STYLE_CONDITIONS_H_
 # define _GNM_STYLE_CONDITIONS_H_
 
-#include "gnumeric.h"
+#include <gnumeric.h>
 #include <dependent.h>
 
 G_BEGIN_DECLS
