@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * fill-series.c: Fill according to a linear or exponential serie.
  *
@@ -25,22 +24,21 @@
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "gnumeric.h"
+#include <gnumeric.h>
 
-#include "sheet.h"
-#include "sheet-filter.h"
-#include "cell.h"
-#include "ranges.h"
-#include "value.h"
-#include "gnm-format.h"
-#include "workbook.h"
-#include "tools.h"
-#include "numbers.h"
-#include "gnm-datetime.h"
+#include <sheet.h>
+#include <sheet-filter.h>
+#include <cell.h>
+#include <ranges.h>
+#include <value.h>
+#include <gnm-format.h>
+#include <workbook.h>
+#include <tools/tools.h>
+#include <numbers.h>
+#include <gnm-datetime.h>
 
-#include "mathfunc.h"
-#include "fill-series.h"
-#include "dao.h"
+#include <mathfunc.h>
+#include <tools/fill-series.h>
 #include <goffice/goffice.h>
 
 static void
