@@ -1,23 +1,23 @@
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "value.h"
-#include "cell.h"
-#include "expr.h"
-#include "expr-deriv.h"
-#include "sheet.h"
-#include "workbook.h"
-#include "rangefunc.h"
-#include "ranges.h"
-#include "gutils.h"
-#include "mathfunc.h"
-#include "gnm-solver.h"
-#include "workbook-view.h"
-#include "workbook-control.h"
-#include "application.h"
-#include "gnm-marshalers.h"
-#include "dao.h"
-#include "gui-util.h"
-#include "gnm-i18n.h"
+#include <gnumeric.h>
+#include <value.h>
+#include <cell.h>
+#include <expr.h>
+#include <expr-deriv.h>
+#include <sheet.h>
+#include <workbook.h>
+#include <rangefunc.h>
+#include <ranges.h>
+#include <gutils.h>
+#include <mathfunc.h>
+#include <tools/gnm-solver.h>
+#include <workbook-view.h>
+#include <workbook-control.h>
+#include <application.h>
+#include <gnm-marshalers.h>
+#include <tools/dao.h>
+#include <gui-util.h>
+#include <gnm-i18n.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-output-stdio.h>
 #include <glib/gi18n-lib.h>
@@ -162,6 +162,24 @@ gnm_solver_constraint_dup (GnmSolverConstraint *c, Sheet *sheet)
 	return res;
 }
 
+static GnmSolverConstraint *
+gnm_solver_constraint_dup1 (GnmSolverConstraint *c)
+{
+	return gnm_solver_constraint_dup (c, c->lhs.sheet);
+}
+
+GType
+gnm_solver_constraint_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0)
+		t = g_boxed_type_register_static ("GnmSolverConstraint",
+			 (GBoxedCopyFunc)gnm_solver_constraint_dup1,
+			 (GBoxedFreeFunc)gnm_solver_constraint_free);
+	return t;
+}
+
 gboolean
 gnm_solver_constraint_equal (GnmSolverConstraint const *a,
 			     GnmSolverConstraint const *b)
@@ -246,6 +264,12 @@ gnm_solver_constraint_valid (GnmSolverConstraint const *c,
 	return TRUE;
 }
 
+/**
+ * gnm_solver_constraint_get_lhs:
+ * @c: GnmSolverConstraint
+ *
+ * Returns: (transfer none) (nullable): Get left-hand side of constraint @c.
+ */
 GnmValue const *
 gnm_solver_constraint_get_lhs (GnmSolverConstraint const *c)
 {
@@ -253,15 +277,25 @@ gnm_solver_constraint_get_lhs (GnmSolverConstraint const *c)
 	return texpr ? gnm_expr_top_get_constant (texpr) : NULL;
 }
 
+/**
+ * gnm_solver_constraint_set_lhs:
+ * @c: GnmSolverConstraint
+ * @v: (transfer full) (nullable): new left-hand side
+ */
 void
 gnm_solver_constraint_set_lhs (GnmSolverConstraint *c, GnmValue *v)
 {
-	/* Takes ownership.  */
 	GnmExprTop const *texpr = v ? gnm_expr_top_new_constant (v) : NULL;
 	dependent_managed_set_expr (&c->lhs, texpr);
 	if (texpr) gnm_expr_top_unref (texpr);
 }
 
+/**
+ * gnm_solver_constraint_get_rhs:
+ * @c: GnmSolverConstraint
+ *
+ * Returns: (transfer none) (nullable): Get right-hand side of constraint @c.
+ */
 GnmValue const *
 gnm_solver_constraint_get_rhs (GnmSolverConstraint const *c)
 {
@@ -269,15 +303,34 @@ gnm_solver_constraint_get_rhs (GnmSolverConstraint const *c)
 	return texpr ? gnm_expr_top_get_constant (texpr) : NULL;
 }
 
+/**
+ * gnm_solver_constraint_set_rhs:
+ * @c: GnmSolverConstraint
+ * @v: (transfer full) (nullable): new right-hand side
+ */
 void
 gnm_solver_constraint_set_rhs (GnmSolverConstraint *c, GnmValue *v)
 {
-	/* Takes ownership.  */
 	GnmExprTop const *texpr = v ? gnm_expr_top_new_constant (v) : NULL;
 	dependent_managed_set_expr (&c->rhs, texpr);
 	if (texpr) gnm_expr_top_unref (texpr);
 }
 
+/**
+ * gnm_solver_constraint_get_part:
+ * @c: GnmSolverConstraint
+ * @sp: GnmSolverParameters
+ * @i: part index
+ * @lhs: (optional) (out): #GnmCell of left-hand side
+ * @cl: (optional) (out): constant value of left-hand side
+ * @rhs: (optional) (out): #GnmCell of right-hand side
+ * @cr: (optional) (out): constant value of left-hand side
+ *
+ * This splits @c into parts and returns information about the @i'th part.
+ * There will be multiple parts when the left-hand side is a cell range.
+ *
+ * Returns: %TRUE if the @i'th part exists.
+ */
 gboolean
 gnm_solver_constraint_get_part (GnmSolverConstraint const *c,
 				GnmSolverParameters const *sp, int i,
@@ -454,6 +507,13 @@ gnm_solver_param_new (Sheet *sheet)
 			     NULL);
 }
 
+/**
+ * gnm_solver_param_dup:
+ * @src: #GnmSolverParameters
+ * @new_sheet: #Sheet
+ *
+ * Returns: (transfer full): duplicate @src, but for @new_sheet.
+ */
 GnmSolverParameters *
 gnm_solver_param_dup (GnmSolverParameters *src, Sheet *new_sheet)
 {
@@ -518,6 +578,12 @@ gnm_solver_param_equal (GnmSolverParameters const *a,
 	return la == lb;
 }
 
+/**
+ * gnm_solver_param_get_input:
+ * @sp: #GnmSolverParameters
+ *
+ * Returns: (transfer none) (nullable): the input cell area.
+ */
 GnmValue const *
 gnm_solver_param_get_input (GnmSolverParameters const *sp)
 {
@@ -526,10 +592,14 @@ gnm_solver_param_get_input (GnmSolverParameters const *sp)
 		: NULL;
 }
 
+/**
+ * gnm_solver_param_set_input:
+ * @sp: #GnmSolverParameters
+ * @v: (transfer full) (nullable): new input area
+ */
 void
 gnm_solver_param_set_input (GnmSolverParameters *sp, GnmValue *v)
 {
-	/* Takes ownership.  */
 	GnmExprTop const *texpr = v ? gnm_expr_top_new_constant (v) : NULL;
 	dependent_managed_set_expr (&sp->input, texpr);
 	if (texpr) gnm_expr_top_unref (texpr);
@@ -548,6 +618,12 @@ cb_grab_cells (GnmCellIter const *iter, gpointer user)
 	return NULL;
 }
 
+/**
+ * gnm_solver_param_get_input_cells:
+ * @sp: #GnmSolverParameters
+ *
+ * Returns: (element-type GnmCell) (transfer container):
+ */
 GPtrArray *
 gnm_solver_param_get_input_cells (GnmSolverParameters const *sp)
 {
@@ -852,14 +928,14 @@ gnm_solver_dispose (GObject *obj)
 		gnm_solver_update_derived (sol);
 	}
 
+	sol->gradient_status = 0;
 	if (sol->gradient) {
-		sol->gradient_status = 0;
 		g_ptr_array_unref (sol->gradient);
 		sol->gradient = NULL;
 	}
 
+	sol->hessian_status = 0;
 	if (sol->hessian) {
-		sol->hessian_status = 0;
 		g_ptr_array_unref (sol->hessian);
 		sol->hessian = NULL;
 	}
@@ -968,7 +1044,7 @@ gnm_solver_set_property (GObject *object, guint property_id,
 }
 
 /**
- * gnm_solver_prepare:
+ * gnm_solver_prepare: (virtual prepare)
  * @sol: solver
  * @wbc: control for user interaction
  * @err: location to store error
@@ -992,7 +1068,7 @@ gnm_solver_prepare (GnmSolver *sol, WorkbookControl *wbc, GError **err)
 }
 
 /**
- * gnm_solver_start:
+ * gnm_solver_start: (virtual start)
  * @sol: solver
  * @wbc: control for user interaction
  * @err: location to store error
@@ -1023,7 +1099,7 @@ gnm_solver_start (GnmSolver *sol, WorkbookControl *wbc, GError **err)
 }
 
 /**
- * gnm_solver_stop:
+ * gnm_solver_stop: (virtual stop)
  * @sol: solver
  * @err: location to store error
  *
@@ -1191,6 +1267,17 @@ gnm_solver_has_solution (GnmSolver *solver)
 	}
 }
 
+static gnm_float
+get_cell_value (GnmCell *cell)
+{
+	GnmValue const *v;
+	gnm_cell_eval (cell);
+	v = cell->value;
+	return VALUE_IS_NUMBER (v) || VALUE_IS_EMPTY (v)
+		? value_get_as_float (v)
+		: gnm_nan;
+}
+
 gboolean
 gnm_solver_check_constraints (GnmSolver *solver)
 {
@@ -1205,10 +1292,10 @@ gnm_solver_check_constraints (GnmSolver *solver)
 
 		for (ui = 0; ui < solver->input_cells->len; ui++) {
 			GnmCell *cell = g_ptr_array_index (solver->input_cells, ui);
-			gnm_float val;
+			gnm_float val = get_cell_value (cell);
 
-			gnm_cell_eval (cell);
-			val = value_get_as_float (cell->value);
+			if (!gnm_finite (val))
+				break;
 			if (sp->options.assume_non_negative && val < 0)
 				break;
 			if (sp->options.assume_discrete &&
@@ -1232,14 +1319,10 @@ gnm_solver_check_constraints (GnmSolver *solver)
 						     &lhs, &cl,
 						     &rhs, &cr);
 		     i++) {
-			if (lhs) {
-				gnm_cell_eval (lhs);
-				cl = value_get_as_float (lhs->value);
-			}
-			if (rhs) {
-				gnm_cell_eval (rhs);
-				cr = value_get_as_float (rhs->value);
-			}
+			if (lhs)
+				cl = get_cell_value (lhs);
+			if (rhs)
+				cr = get_cell_value (rhs);
 
 			switch (c->type) {
 			case GNM_SOLVER_INTEGER:
@@ -1376,15 +1459,16 @@ cell_in_cr (GnmSolver *sol, GnmCell const *cell, gboolean follow)
 static gboolean
 cell_is_constant (GnmCell *cell, gnm_float *pc)
 {
-	if (!cell)
+	if (!cell) {
+		*pc = 0;
 		return TRUE;
+	}
 
 	if (cell->base.texpr)
 		return FALSE;
 
-	gnm_cell_eval (cell);
-	*pc = value_get_as_float (cell->value);
-	return TRUE;
+	*pc = get_cell_value (cell);
+	return gnm_finite (*pc);
 }
 
 #define SET_LOWER(l_)						\
@@ -1685,14 +1769,10 @@ gnm_solver_create_program_report (GnmSolver *solver, const char *name)
 			dao_set_cell (dao, 1, R, ctxt);
 			g_free (ctxt);
 
-			if (lhs) {
-				gnm_cell_eval (lhs);
-				cl = value_get_as_float (lhs->value);
-			}
-			if (rhs) {
-				gnm_cell_eval (rhs);
-				cr = value_get_as_float (rhs->value);
-			}
+			if (lhs)
+				cl = get_cell_value (lhs);
+			if (rhs)
+				cr = get_cell_value (rhs);
 
 			switch (c->type) {
 			case GNM_SOLVER_INTEGER: {
@@ -1834,14 +1914,10 @@ gnm_solver_create_sensitivity_report (GnmSolver *solver, const char *name)
 			dao_set_cell (dao, 1, R, ctxt);
 			g_free (ctxt);
 
-			if (lhs) {
-				gnm_cell_eval (lhs);
-				cl = value_get_as_float (lhs->value);
-			}
-			if (rhs) {
-				gnm_cell_eval (rhs);
-				cr = value_get_as_float (rhs->value);
-			}
+			if (lhs)
+				cl = get_cell_value (lhs);
+			if (rhs)
+				cr = get_cell_value (rhs);
 
 			add_value_or_special (dao, 2, R, sols->constraints[cidx].shadow_price);
 			add_value_or_special (dao, 3, R, cl);
@@ -1885,7 +1961,7 @@ gnm_solver_create_report (GnmSolver *solver, const char *base)
 
 /**
  * gnm_solver_get_target_value:
- * @isol: solver
+ * @solver: solver
  *
  * Returns: the current value of the target cell, possibly with the sign
  * flipped.
@@ -1893,16 +1969,8 @@ gnm_solver_create_report (GnmSolver *solver, const char *base)
 gnm_float
 gnm_solver_get_target_value (GnmSolver *solver)
 {
-	GnmValue const *v;
-
-	gnm_cell_eval (solver->target);
-	v = solver->target->value;
-
-	if (VALUE_IS_NUMBER (v) || VALUE_IS_EMPTY (v)) {
-		gnm_float y = value_get_as_float (v);
-		return solver->flip_sign ? 0 - y : y;
-	} else
-		return gnm_nan;
+	gnm_float y = get_cell_value (solver->target);
+	return solver->flip_sign ? 0 - y : y;
 }
 
 void
@@ -1929,6 +1997,12 @@ gnm_solver_set_vars (GnmSolver *sol, gnm_float const *xs)
 		gnm_solver_set_var (sol, i, xs[i]);
 }
 
+/**
+ * gnm_solver_save_vars:
+ * @sol: #GnmSolver
+ *
+ * Returns: (transfer full) (element-type GnmValue):
+ */
 GPtrArray *
 gnm_solver_save_vars (GnmSolver *sol)
 {
@@ -1943,6 +2017,11 @@ gnm_solver_save_vars (GnmSolver *sol)
 	return vals;
 }
 
+/**
+ * gnm_solver_restore_vars:
+ * @sol: #GnmSolver
+ * @vals: (transfer full) (element-type GnmValue): values to restore
+ */
 void
 gnm_solver_restore_vars (GnmSolver *sol, GPtrArray *vals)
 {
@@ -1983,6 +2062,8 @@ gnm_solver_has_analytic_gradient (GnmSolver *sol)
 			else {
 				if (gnm_solver_debug ())
 					g_printerr ("Unable to compute analytic gradient\n");
+				g_ptr_array_unref (sol->gradient);
+				sol->gradient = NULL;
 				sol->gradient_status++;
 				break;
 			}
@@ -2018,11 +2099,11 @@ gnm_solver_compute_gradient_analytically (GnmSolver *sol, gnm_float const *xs)
 }
 
 /**
- * gnm_solver_compute_gradient:
+ * gnm_solver_compute_gradient: (skip)
  * @sol: Solver
  * @xs: Point to compute gradient at
  *
- * Returns: (transfer full): A vector containing the gradient.  This
+ * Returns: xxx(transfer full): A vector containing the gradient.  This
  * function takes the flip-sign property into account.  This will use
  * analytic gradient, if possible, and a numerical approximation otherwise.
  */
@@ -2129,7 +2210,7 @@ gnm_solver_has_analytic_hessian (GnmSolver *sol)
 		}
 	}
 
-	gnm_expr_deriv_info_free (info);
+	gnm_expr_deriv_info_unref (info);
 
 	return sol->hessian_status == 1;
 }
@@ -2139,10 +2220,8 @@ gnm_solver_has_analytic_hessian (GnmSolver *sol)
  * @sol: Solver
  * @xs: Point to compute Hessian at
  *
- * Returns: (transfer full): A vector containing the Hessian.  This
- * function takes the flip-sign property into account.  The result vector
- * will be n+(n-1)+...+2+1 elements long containing the triangular
- * Hessian.  Use symmetry to obtain the full Hessian.
+ * Returns: (transfer full): A matrix containing the Hessian.  This
+ * function takes the flip-sign property into account.
  */
 GnmMatrix *
 gnm_solver_compute_hessian (GnmSolver *sol, gnm_float const *xs)
@@ -2406,14 +2485,14 @@ gnm_solver_pick_lp_coords (GnmSolver *sol,
 }
 
 /**
- * gnm_solver_get_lp_coeffs:
+ * gnm_solver_get_lp_coeffs: (skip)
  * @sol: Solver
  * @ycell: Cell for which to compute coefficients
  * @x1: first coordinate value
  * @x2: second coordinate value
  * @err: error location
  *
- * Returns: (transfer full) (nullable): coordinates, or %NULL in case of error.
+ * Returns: xxx(transfer full) (nullable): coordinates, or %NULL in case of error.
  * Note: this function is not affected by the flip-sign property, even
  * if @ycell happens to coindice with the solver target cell.
  */
@@ -2428,8 +2507,7 @@ gnm_solver_get_lp_coeffs (GnmSolver *sol, GnmCell *ycell,
 	gnm_float y0;
 
 	gnm_solver_set_vars (sol, x1);
-	gnm_cell_eval (ycell);
-	y0 = VALUE_IS_NUMBER (ycell->value) ? value_get_as_float (ycell->value) : gnm_nan;
+	y0 = get_cell_value (ycell);
 	if (!gnm_finite (y0))
 		goto fail_calc;
 
@@ -2442,8 +2520,7 @@ gnm_solver_get_lp_coeffs (GnmSolver *sol, GnmCell *ycell,
 		}
 
 		gnm_solver_set_var (sol, ui, x2[ui]);
-		gnm_cell_eval (ycell);
-		y1 = VALUE_IS_NUMBER (ycell->value) ? value_get_as_float (ycell->value) : gnm_nan;
+		y1 = get_cell_value (ycell);
 
 		dy = y1 - y0;
 		res[ui] = dy / dx;
@@ -2456,8 +2533,7 @@ gnm_solver_get_lp_coeffs (GnmSolver *sol, GnmCell *ycell,
 			x01 = (x1[ui] + x2[ui]) / 2;
 			if (sol->discrete[ui]) x01 = gnm_floor (x01);
 			gnm_solver_set_var (sol, ui, x01);
-			gnm_cell_eval (ycell);
-			y01 = VALUE_IS_NUMBER (ycell->value) ? value_get_as_float (ycell->value) : gnm_nan;
+			y01 = get_cell_value (ycell);
 			if (!gnm_finite (y01))
 				goto fail_calc;
 
@@ -2900,6 +2976,9 @@ cb_child_exit (G_GNUC_UNUSED GPid pid, gint status, GnmSubSolver *subsol)
 	}
 }
 
+/**
+ * gnm_sub_solver_spawn: (skip)
+ */
 gboolean
 gnm_sub_solver_spawn (GnmSubSolver *subsol,
 		      char **argv,
@@ -3183,6 +3262,9 @@ gnm_solver_iterator_iterate (GnmSolverIterator *iter)
 	return progress;
 }
 
+/**
+ * gnm_solver_iterator_new_func: (skip)
+ */
 GnmSolverIterator *
 gnm_solver_iterator_new_func (GCallback iterate, gpointer user)
 {
@@ -3636,14 +3718,17 @@ GSF_CLASS (GnmIterSolver, gnm_iter_solver,
 static GObjectClass *gnm_solver_factory_parent_class;
 
 static void
-gnm_solver_factory_dispose (GObject *obj)
+gnm_solver_factory_finalize (GObject *obj)
 {
 	GnmSolverFactory *factory = GNM_SOLVER_FACTORY (obj);
 
+	if (factory->notify)
+		factory->notify (factory->data);
+
 	g_free (factory->id);
 	g_free (factory->name);
 
-	gnm_solver_factory_parent_class->dispose (obj);
+	gnm_solver_factory_parent_class->finalize (obj);
 }
 
 static void
@@ -3652,7 +3737,7 @@ gnm_solver_factory_class_init (GObjectClass *object_class)
 	gnm_solver_factory_parent_class =
 		g_type_class_peek_parent (object_class);
 
-	object_class->dispose = gnm_solver_factory_dispose;
+	object_class->finalize = gnm_solver_factory_finalize;
 }
 
 GSF_CLASS (GnmSolverFactory, gnm_solver_factory,
@@ -3661,18 +3746,38 @@ GSF_CLASS (GnmSolverFactory, gnm_solver_factory,
 
 static GSList *solvers;
 
+/**
+ * gnm_solver_db_get:
+ *
+ * Returns: (transfer none) (element-type GnmSolverFactory): list of
+ * registered solver factories.
+ */
 GSList *
 gnm_solver_db_get (void)
 {
 	return solvers;
 }
 
+/**
+ * gnm_solver_factory_new:
+ * @id: Unique identifier
+ * @name: Translated name for UI purposes
+ * @type: Model type created by factory
+ * @creator: (scope notified): callback for creating a solver
+ * @functional: (scope notified): callback for checking if factory is functional
+ * @data: User pointer for @creator and @functional
+ * @notify: Destroy notification for @data.
+ *
+ * Returns: (transfer full): a new #GnmSolverFactory
+ */
 GnmSolverFactory *
 gnm_solver_factory_new (const char *id,
 			const char *name,
 			GnmSolverModelType type,
 			GnmSolverCreator creator,
-			GnmSolverFactoryFunctional functional)
+			GnmSolverFactoryFunctional functional,
+			gpointer data,
+			GDestroyNotify notify)
 {
 	GnmSolverFactory *res;
 
@@ -3686,15 +3791,24 @@ gnm_solver_factory_new (const char *id,
 	res->type = type;
 	res->creator = creator;
 	res->functional = functional;
+	res->data = data;
+	res->notify = notify;
 	return res;
 }
 
+/**
+ * gnm_solver_factory_create:
+ * @factory: #GnmSolverFactory
+ * @param: #GnmSolverParameters
+ *
+ * Returns: (transfer full): a new #GnmSolver
+ */
 GnmSolver *
 gnm_solver_factory_create (GnmSolverFactory *factory,
 			   GnmSolverParameters *param)
 {
 	g_return_val_if_fail (GNM_IS_SOLVER_FACTORY (factory), NULL);
-	return factory->creator (factory, param);
+	return factory->creator (factory, param, factory->data);
 }
 
 gboolean
@@ -3705,7 +3819,7 @@ gnm_solver_factory_functional (GnmSolverFactory *factory,
 		return FALSE;
 
 	return (factory->functional == NULL ||
-		factory->functional (factory, wbcg));
+		factory->functional (factory, wbcg, factory->data));
 }
 
 static int
