@@ -12,10 +12,13 @@
 #endif
 
 #include <gnumeric-config.h>
-#include "numbers.h"
-#include "gnumeric.h"
-#include "goal-seek.h"
-#include "gnm-random.h"
+#include <numbers.h>
+#include <gnumeric.h>
+#include <tools/goal-seek.h>
+#include <gnm-random.h>
+#include <value.h>
+#include <cell.h>
+#include <sheet.h>
 
 #include <stdlib.h>
 #include <math.h>
@@ -23,7 +26,7 @@
 
 
 static gboolean
-update_data (gnm_float x, gnm_float y, GoalSeekData *data)
+update_data (gnm_float x, gnm_float y, GnmGoalSeekData *data)
 {
 	if (!gnm_finite (y))
 		return FALSE;
@@ -89,12 +92,12 @@ update_data (gnm_float x, gnm_float y, GoalSeekData *data)
  * Calculate a reasonable approximation to the derivative of a function
  * in a single point.
  */
-static GoalSeekStatus
-fake_df (GoalSeekFunction f, gnm_float x, gnm_float *dfx, gnm_float xstep,
-	 GoalSeekData *data, void *user_data)
+static GnmGoalSeekStatus
+fake_df (GnmGoalSeekFunction f, gnm_float x, gnm_float *dfx, gnm_float xstep,
+	 GnmGoalSeekData *data, void *user_data)
 {
 	gnm_float xl, xr, yl, yr;
-	GoalSeekStatus status;
+	GnmGoalSeekStatus status;
 
 #ifdef DEBUG_GOAL_SEEK
 	g_print ("fake_df (x=%.20" GNM_FORMAT_g ", xstep=%.20" GNM_FORMAT_g ")\n",
@@ -148,7 +151,7 @@ fake_df (GoalSeekFunction f, gnm_float x, gnm_float *dfx, gnm_float xstep,
 }
 
 void
-goal_seek_initialize (GoalSeekData *data)
+goal_seek_initialize (GnmGoalSeekData *data)
 {
 	data->havexpos = data->havexneg = data->have_root = FALSE;
 	data->xpos = data->xneg = data->root = gnm_nan;
@@ -159,14 +162,22 @@ goal_seek_initialize (GoalSeekData *data)
 }
 
 
-/*
+/**
+ * goal_seek_point:
+ * @f: (scope call): object function
+ * @data: #GnmGoalSeekData state
+ * @user_data: user data for @f
+ * @x0: root guess
+ *
  * Seek a goal using a single point.
+ *
+ * Returns:
  */
-GoalSeekStatus
-goal_seek_point (GoalSeekFunction f, GoalSeekData *data,
+GnmGoalSeekStatus
+goal_seek_point (GnmGoalSeekFunction f, GnmGoalSeekData *data,
 		 void *user_data, gnm_float x0)
 {
-	GoalSeekStatus status;
+	GnmGoalSeekStatus status;
 	gnm_float y0;
 
 	if (data->have_root)
@@ -190,9 +201,9 @@ goal_seek_point (GoalSeekFunction f, GoalSeekData *data,
 }
 
 
-static GoalSeekStatus
-goal_seek_newton_polish (GoalSeekFunction f, GoalSeekFunction df,
-			 GoalSeekData *data, void *user_data,
+static GnmGoalSeekStatus
+goal_seek_newton_polish (GnmGoalSeekFunction f, GnmGoalSeekFunction df,
+			 GnmGoalSeekData *data, void *user_data,
 			 gnm_float x0, gnm_float y0)
 {
 	int iterations;
@@ -208,7 +219,7 @@ goal_seek_newton_polish (GoalSeekFunction f, GoalSeekFunction df,
 		if (try_square) {
 			gnm_float x1 = x0 * gnm_abs (x0);
 			gnm_float y1, r;
-			GoalSeekStatus status = f (x1, &y1, user_data);
+			GnmGoalSeekStatus status = f (x1, &y1, user_data);
 			if (status != GOAL_SEEK_OK)
 				goto nomore_square;
 
@@ -235,7 +246,7 @@ goal_seek_newton_polish (GoalSeekFunction f, GoalSeekFunction df,
 
 		if (try_newton) {
 			gnm_float df0, r, x1, y1;
-			GoalSeekStatus status = df
+			GnmGoalSeekStatus status = df
 				? df (x0, &df0, user_data)
 				: fake_df (f, x0, &df0, gnm_abs (x0) / 1e6, data, user_data);
 			if (status != GOAL_SEEK_OK || df0 == 0)
@@ -285,11 +296,18 @@ goal_seek_newton_polish (GoalSeekFunction f, GoalSeekFunction df,
 }
 
 
-/*
+/**
+ * goal_seek_newton:
+ * @f: (scope call): object function
+ * @df: (scope call) (nullable): object function derivative
+ * @data: #GnmGoalSeekData state
+ * @user_data: user data for @f and @df
+ * @x0: root guess
+ *
  * Seek a goal (root) using Newton's iterative method.
  *
  * The supplied function must (should) be continously differentiable in
- * the supplied interval.  If NULL is used for `df', this function will
+ * the supplied interval.  If @df is %NULL, this function will
  * estimate the derivative.
  *
  * This method will find a root rapidly provided the initial guess, x0,
@@ -297,9 +315,9 @@ goal_seek_newton_polish (GoalSeekFunction f, GoalSeekFunction df,
  * (asympotically) goes like i^2 unless the root is a multiple root in
  * which case it is only like c*i.)
  */
-GoalSeekStatus
-goal_seek_newton (GoalSeekFunction f, GoalSeekFunction df,
-		  GoalSeekData *data, void *user_data, gnm_float x0)
+GnmGoalSeekStatus
+goal_seek_newton (GnmGoalSeekFunction f, GnmGoalSeekFunction df,
+		  GnmGoalSeekData *data, void *user_data, gnm_float x0)
 {
 	int iterations;
 	gnm_float precision = data->precision / 2;
@@ -315,7 +333,7 @@ goal_seek_newton (GoalSeekFunction f, GoalSeekFunction df,
 
 	for (iterations = 0; iterations < 100; iterations++) {
 		gnm_float x1, y0, df0, stepsize;
-		GoalSeekStatus status;
+		GnmGoalSeekStatus status;
 		gboolean flat;
 
 #ifdef DEBUG_GOAL_SEEK
@@ -416,7 +434,12 @@ goal_seek_newton (GoalSeekFunction f, GoalSeekFunction df,
 	return GOAL_SEEK_ERROR;
 }
 
-/*
+/**
+ * goal_seek_bisection:
+ * @f: (scope call): object function
+ * @data: #GnmGoalSeekData state.
+ * @user_data: user data for @f.
+ *
  * Seek a goal (root) using bisection methods.
  *
  * The supplied function must (should) be continous over the interval.
@@ -431,9 +454,9 @@ goal_seek_newton (GoalSeekFunction f, GoalSeekFunction df,
  * nowhere), and Ridder's Method (usually fast, harder to fool than
  * the secant method).
  */
-
-GoalSeekStatus
-goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
+GnmGoalSeekStatus
+goal_seek_bisection (GnmGoalSeekFunction f, GnmGoalSeekData *data,
+		     void *user_data)
 {
 	int iterations;
 	gnm_float stepsize;
@@ -455,7 +478,7 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 	/* log_2 (10) = 3.3219 < 4.  */
 	for (iterations = 0; iterations < 100 + GNM_DIG * 4; iterations++) {
 		gnm_float xmid, ymid;
-		GoalSeekStatus status;
+		GnmGoalSeekStatus status;
 		enum { M_SECANT, M_RIDDER, M_NEWTON, M_MIDPOINT } method;
 
 		method = (iterations % 4 == 0)
@@ -594,9 +617,18 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 #undef SECANT_P
 #undef RIDDER_P
 
-GoalSeekStatus
-goal_seek_trawl_uniformly (GoalSeekFunction f,
-			   GoalSeekData *data, void *user_data,
+/**
+ * goal_seek_trawl_uniformly:
+ * @f: (scope call): object function
+ * @data: #GnmGoalSeekData state
+ * @user_data: user data for @f
+ * @xmin: lower search bound
+ * @xmax: upper search bound
+ * @points: number of points to try.
+ */
+GnmGoalSeekStatus
+goal_seek_trawl_uniformly (GnmGoalSeekFunction f,
+			   GnmGoalSeekData *data, void *user_data,
 			   gnm_float xmin, gnm_float xmax,
 			   int points)
 {
@@ -614,7 +646,7 @@ goal_seek_trawl_uniformly (GoalSeekFunction f,
 
 	for (i = 0; i < points; i++) {
 		gnm_float x, y;
-		GoalSeekStatus status;
+		GnmGoalSeekStatus status;
 
 		if (data->havexpos && data->havexneg)
 			break;
@@ -639,9 +671,18 @@ goal_seek_trawl_uniformly (GoalSeekFunction f,
 	return GOAL_SEEK_ERROR;
 }
 
-GoalSeekStatus
-goal_seek_trawl_normally (GoalSeekFunction f,
-			  GoalSeekData *data, void *user_data,
+/**
+ * goal_seek_trawl_normally:
+ * @f: (scope call): object function
+ * @data: #GnmGoalSeekData state
+ * @user_data: user data for @f
+ * @mu: search mean
+ * @sigma: search standard deviation
+ * @points: number of points to try.
+ */
+GnmGoalSeekStatus
+goal_seek_trawl_normally (GnmGoalSeekFunction f,
+			  GnmGoalSeekData *data, void *user_data,
 			  gnm_float mu, gnm_float sigma,
 			  int points)
 {
@@ -659,7 +700,7 @@ goal_seek_trawl_normally (GoalSeekFunction f,
 
 	for (i = 0; i < points; i++) {
 		gnm_float x, y;
-		GoalSeekStatus status;
+		GnmGoalSeekStatus status;
 
 		if (data->havexpos && data->havexneg)
 			break;
@@ -687,35 +728,159 @@ goal_seek_trawl_normally (GoalSeekFunction f,
 	return GOAL_SEEK_ERROR;
 }
 
-#ifdef STANDALONE
-static GoalSeekStatus
-f (gnm_float x, gnm_float *y, void *user_data)
+/**
+ * gnm_goal_seek_eval_cell:
+ * @x: x-value for which to evaluate
+ * @y: (out): location to store result
+ * @data: user data
+ *
+ * Returns: An status indicating whether evaluation went ok.
+ */
+GnmGoalSeekStatus
+gnm_goal_seek_eval_cell (gnm_float x, gnm_float *y, gpointer data_)
 {
-	*y = x * x - 2;
-	return GOAL_SEEK_OK;
+	GnmGoalSeekCellData const *data = data_;
+	GnmValue *v = value_new_float (x);
+
+	gnm_cell_set_value (data->xcell, v);
+	cell_queue_recalc (data->xcell);
+	gnm_cell_eval (data->ycell);
+
+	if (data->ycell->value &&
+	    VALUE_IS_NUMBER (data->ycell->value)) {
+		*y = value_get_as_float (data->ycell->value) - data->ytarget;
+		if (gnm_finite (*y))
+			return GOAL_SEEK_OK;
+	}
+
+	return GOAL_SEEK_ERROR;
 }
 
-static GoalSeekStatus
-df (gnm_float x, gnm_float *y, void *user_data)
+GnmGoalSeekStatus
+gnm_goal_seek_cell (GnmGoalSeekData *data,
+		    GnmGoalSeekCellData *celldata)
 {
-	*y = 2 * x;
-	return GOAL_SEEK_OK;
+	GnmGoalSeekStatus status;
+	gboolean hadold;
+	gnm_float oldx;
+	GnmValue *v;
+
+	hadold = !VALUE_IS_EMPTY_OR_ERROR (celldata->xcell->value);
+	oldx = hadold ? value_get_as_float (celldata->xcell->value) : 0;
+
+	/* PLAN A: Newton's iterative method from initial or midpoint.  */
+	{
+		gnm_float x0;
+
+		if (hadold && oldx >= data->xmin && oldx <= data->xmax)
+			x0 = oldx;
+		else
+			x0 = (data->xmin + data->xmax) / 2;
+
+		status = goal_seek_newton (gnm_goal_seek_eval_cell, NULL,
+					   data, celldata,
+					   x0);
+		if (status == GOAL_SEEK_OK)
+			goto DONE;
+	}
+
+	/* PLAN B: Trawl uniformly.  */
+	if (!data->havexpos || !data->havexneg) {
+		status = goal_seek_trawl_uniformly (gnm_goal_seek_eval_cell,
+						    data, celldata,
+						    data->xmin, data->xmax,
+						    100);
+		if (status == GOAL_SEEK_OK)
+			goto DONE;
+	}
+
+	/* PLAN C: Trawl normally from middle.  */
+	if (!data->havexpos || !data->havexneg) {
+		gnm_float sigma, mu;
+		int i;
+
+		sigma = MIN (data->xmax - data->xmin, 1e6);
+		mu = (data->xmax + data->xmin) / 2;
+
+		for (i = 0; i < 5; i++) {
+			sigma /= 10;
+			status = goal_seek_trawl_normally (gnm_goal_seek_eval_cell,
+							   data, celldata,
+							   mu, sigma, 30);
+			if (status == GOAL_SEEK_OK)
+				goto DONE;
+		}
+	}
+
+	/* PLAN D: Trawl normally from left.  */
+	if (!data->havexpos || !data->havexneg) {
+		gnm_float sigma, mu;
+		int i;
+
+		sigma = MIN (data->xmax - data->xmin, 1e6);
+		mu = data->xmin;
+
+		for (i = 0; i < 5; i++) {
+			sigma /= 10;
+			status = goal_seek_trawl_normally (gnm_goal_seek_eval_cell,
+							   data, celldata,
+							   mu, sigma, 20);
+			if (status == GOAL_SEEK_OK)
+				goto DONE;
+		}
+	}
+
+	/* PLAN E: Trawl normally from right.  */
+	if (!data->havexpos || !data->havexneg) {
+		gnm_float sigma, mu;
+		int i;
+
+		sigma = MIN (data->xmax - data->xmin, 1e6);
+		mu = data->xmax;
+
+		for (i = 0; i < 5; i++) {
+			sigma /= 10;
+			status = goal_seek_trawl_normally (gnm_goal_seek_eval_cell,
+							   data, celldata,
+							   mu, sigma, 20);
+			if (status == GOAL_SEEK_OK)
+				goto DONE;
+		}
+	}
+
+	/* PLAN F: Newton iteration with uniform net of starting points.  */
+	if (!data->havexpos || !data->havexneg) {
+		int i;
+		const int N = 10;
+
+		for (i = 1; i <= N; i++) {
+			gnm_float x0 =	data->xmin +
+				(data->xmax - data->xmin) / (N + 1) * i;
+
+			status = goal_seek_newton (gnm_goal_seek_eval_cell, NULL,
+						   data, celldata,
+						   x0);
+			if (status == GOAL_SEEK_OK)
+				goto DONE;
+		}
+	}
+
+	/* PLAN Z: Bisection.  */
+	{
+		status = goal_seek_bisection (gnm_goal_seek_eval_cell,
+					      data, celldata);
+		if (status == GOAL_SEEK_OK)
+			goto DONE;
+	}
+
+ DONE:
+	if (status == GOAL_SEEK_OK)
+		v = value_new_float (data->root);
+	else if (hadold)
+		v = value_new_float (oldx);
+	else
+		v = value_new_empty ();
+	sheet_cell_set_value (celldata->xcell, v);
+
+	return status;
 }
-
-
-int
-main ()
-{
-	GoalSeekData data;
-
-	goal_seek_initialize (&data);
-	data.xmin = -100;
-	data.xmax = 100;
-
-	goal_seek_newton (f, NULL, &data, NULL, 50.0);
-
-	goal_seek_newton (f, df, &data, NULL, 50.0);
-
-	return 0;
-}
-#endif
