@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * scenarios.c:
  *
@@ -31,10 +30,10 @@
 #include <workbook.h>
 #include <expr.h>
 
-#include "scenarios.h"
-#include "dao.h"
-#include "clipboard.h"
-#include "parse-util.h"
+#include <tools/scenarios.h>
+#include <tools/dao.h>
+#include <clipboard.h>
+#include <parse-util.h>
 #include <goffice/goffice.h>
 
 #include <string.h>
@@ -172,8 +171,8 @@ gnm_scenario_dup (GnmScenario *src, Sheet *new_sheet)
 
 	dst = gnm_scenario_new (src->name, new_sheet);
 	gnm_scenario_set_comment (dst, src->comment);
-	dst->items = go_slist_map (src->items,
-				   (GOMapFunc)gnm_scenario_item_dup);
+	dst->items = g_slist_copy_deep
+		(src->items, (GCopyFunc)gnm_scenario_item_dup, NULL);
 	return dst;
 }
 
