@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * validation.c: Implementation of validation.
  *
@@ -22,25 +21,25 @@
  */
 
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "validation.h"
-#include "validation-combo.h"
+#include <gnumeric.h>
+#include <validation.h>
+#include <validation-combo.h>
 
-#include "numbers.h"
-#include "expr.h"
-#include "mstyle.h"
-#include "sheet.h"
-#include "cell.h"
-#include "value.h"
-#include "workbook.h"
-#include "workbook-control.h"
-#include "parse-util.h"
+#include <numbers.h>
+#include <expr.h>
+#include <mstyle.h>
+#include <sheet.h>
+#include <cell.h>
+#include <value.h>
+#include <workbook.h>
+#include <workbook-control.h>
+#include <parse-util.h>
 
-#include "sheet-view.h"
-#include "sheet-object.h"
-#include "sheet-style.h"
-#include "gnm-validation-combo-view.h"
-#include "gnm-cell-combo-view.h"
+#include <sheet-view.h>
+#include <sheet-object.h>
+#include <sheet-style.h>
+#include <widgets/gnm-validation-combo-view.h>
+#include <widgets/gnm-cell-combo-view.h>
 #include <gsf/gsf-impl-utils.h>
 
 #include <glib/gi18n-lib.h>
@@ -231,16 +230,22 @@ gnm_validation_op_get_type (void)
 
 /**
  * gnm_validation_new:
+ * @style: #ValidationStyle
+ * @op: #ValidationOp
+ * @sheet: #Sheet
  * @title: will be copied.
  * @msg: will be copied.
- * @texpr0: absorb the reference to the expression (optionally %NULL).
- * @texpr1: absorb the reference to the expression (optionally %NULL).
+ * @texpr0: (transfer full) (nullable): first expression
+ * @texpr1: (transfer full) (nullable): second expression
+ * @allow_blank:
+ * @use_dropdown:
  *
  * Does _NOT_ require all necessary information to be set here.
  * gnm_validation_set_expr can be used to change the expressions after creation,
- * and gnm_validation_is_ok can be used to ensure that things are properly setup.
+ * and gnm_validation_is_ok can be used to ensure that things are properly
+ * setup.
  *
- * Returns a new @GnmValidation object that needs to be unrefed.
+ * Returns: (transfer full): a new @GnmValidation object
  **/
 GnmValidation *
 gnm_validation_new (ValidationStyle style,
@@ -380,14 +385,12 @@ gnm_validation_unref (GnmValidation const *val)
 	if (v->ref_count < 1) {
 		int i;
 
-		if (v->title != NULL) {
-			go_string_unref (v->title);
-			v->title = NULL;
-		}
-		if (v->msg != NULL) {
-			go_string_unref (v->msg);
-			v->msg = NULL;
-		}
+		go_string_unref (v->title);
+		v->title = NULL;
+
+		go_string_unref (v->msg);
+		v->msg = NULL;
+
 		for (i = 0 ; i < 2 ; i++)
 			dependent_managed_set_expr (&v->deps[i], NULL);
 		g_free (v);
@@ -517,12 +520,16 @@ cb_validate_custom (GnmValueIter const *v_iter, GnmValue const *target)
  * @wbc:
  * @mstyle:
  * @sheet:
+ * @pos:
+ * @showed_dialog: (out) (optional):
  *
- * validation set in the GnmStyle if applicable.
+ * Checks the validation in @mstyle, if any.  Set @showed_dialog to %TRUE
+ * if a dialog was showed as a result.
  **/
 ValidationStatus
 gnm_validation_eval (WorkbookControl *wbc, GnmStyle const *mstyle,
-		 Sheet *sheet, GnmCellPos const *pos, gboolean *showed_dialog)
+		     Sheet *sheet, GnmCellPos const *pos,
+		     gboolean *showed_dialog)
 {
 	GnmValidation const *v;
 	GnmCell *cell;
@@ -733,8 +740,9 @@ validation_eval_range_cb (GnmCellIter const *iter, validation_eval_t *closure)
 
 ValidationStatus
 gnm_validation_eval_range (WorkbookControl *wbc,
-		       Sheet *sheet, GnmCellPos const *pos, GnmRange const *r,
-		       gboolean *showed_dialog)
+			   Sheet *sheet, GnmCellPos const *pos,
+			   GnmRange const *r,
+			   gboolean *showed_dialog)
 {
 	GnmValue *result;
 	validation_eval_t closure;
