@@ -1,9 +1,8 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_VALIDATION_H_
 # define _GNM_VALIDATION_H_
 
-#include "gnumeric.h"
-#include "dependent.h"
+#include <gnumeric.h>
+#include <dependent.h>
 
 G_BEGIN_DECLS
 
@@ -79,7 +78,7 @@ gboolean    gnm_validation_equal    (GnmValidation const *a,
 				     GnmValidation const *b,
 				     gboolean relax_sheet);
 
-void        gnm_validation_ref      (GnmValidation const *v);
+GnmValidation *gnm_validation_ref      (GnmValidation const *v);
 void        gnm_validation_unref    (GnmValidation const *v);
 
 void	    gnm_validation_set_expr (GnmValidation *v,
