@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * gnm-filter-combo.c: the autofilter combo box for the goffice canvas
@@ -22,29 +21,28 @@
  */
 
 #include <gnumeric-config.h>
-#include "gnm-filter-combo-view.h"
-#include "gnm-cell-combo-view-impl.h"
+#include <widgets/gnm-filter-combo-view.h>
+#include <widgets/gnm-cell-combo-view-impl.h>
 
-#include "gnumeric.h"
-#include "sheet-filter.h"
-#include "sheet-filter-combo.h"
-#include "gnm-format.h"
-#include "value.h"
-#include "cell.h"
-#include "commands.h"
-#include "sheet.h"
-#include "sheet-object-impl.h"
-#include "wbc-gtk.h"
-#include "workbook.h"
-#include "style-color.h"
-#include "sheet-control-gui.h"
-#include "../dialogs/dialogs.h"
-#include "wbc-gtk-impl.h"
+#include <gnumeric.h>
+#include <sheet-filter.h>
+#include <sheet-filter-combo.h>
+#include <gnm-format.h>
+#include <value.h>
+#include <cell.h>
+#include <commands.h>
+#include <sheet.h>
+#include <sheet-object-impl.h>
+#include <wbc-gtk.h>
+#include <workbook.h>
+#include <style-color.h>
+#include <sheet-control-gui.h>
+#include <dialogs/dialogs.h>
+#include <wbc-gtk-impl.h>
 #include <undo.h>
 
 #include <goffice/goffice.h>
 #include <gsf/gsf-impl-utils.h>
-#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
 
