@@ -1,7 +1,7 @@
 /* Mostly a copy of gtkfontbutton.c awaiting a fix for 695776.  */
 
 #include <gnumeric-config.h>
-#include "gnm-fontbutton.h"
+#include <widgets/gnm-fontbutton.h>
 
 typedef enum {
   GTK_FONT_CHOOSER_PROP_FIRST           = 0x4000,
@@ -1151,7 +1151,7 @@ gnm_font_button_create_inside (GnmFontButton *font_button)
 {
   GtkWidget *widget;
 
-  gtk_widget_push_composite_child ();
+  //gtk_widget_push_composite_child ();
 
   widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
@@ -1169,7 +1169,7 @@ gnm_font_button_create_inside (GnmFontButton *font_button)
 
   gtk_widget_show_all (widget);
 
-  gtk_widget_pop_composite_child ();
+  //gtk_widget_pop_composite_child ();
 
   return widget;
 }
