@@ -1,4 +1,4 @@
-/**
+/*
  * gnm-notebook.c: Implements a button-only notebook.
  *
  * Copyright (c) 2008 Morten Welinder <terra@gnome.org>
@@ -15,18 +15,27 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  **/
 
 #include <gnumeric-config.h>
-#include "gnm-notebook.h"
+#include <widgets/gnm-notebook.h>
 #include <goffice/goffice.h>
-#include "gnm-i18n.h"
+#include <gnm-i18n.h>
 #include <gsf/gsf-impl-utils.h>
 
 /* ------------------------------------------------------------------------- */
 
+/**
+ * gnm_notebook_get_nth_label: (skip)
+ */
+
+/**
+ * gnm_notebook_get_current_label: (skip)
+ */
+
+/* ------------------------------------------------------------------------- */
+
 struct GnmNotebookButton_ {
 	/*
 	 * We need to derive from GtkLabel mostly for theming reasons,
