@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * workbook.c: workbook model and manipulation utilities
@@ -13,39 +12,39 @@
  * Copyright (C) 1999-2009 Morten Welinder (terra@gnome.org)
  */
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "workbook-priv.h"
-#include "compilation.h"
+#include <gnumeric.h>
+#include <workbook-priv.h>
+#include <compilation.h>
 
-#include "workbook-view.h"
-#include "workbook-control.h"
-#include "command-context.h"
-#include "application.h"
-#include "gnumeric-conf.h"
-#include "sheet.h"
-#include "sheet-view.h"
-#include "sheet-control.h"
-#include "cell.h"
-#include "expr.h"
-#include "expr-name.h"
-#include "dependent.h"
-#include "value.h"
-#include "ranges.h"
-#include "history.h"
-#include "commands.h"
-#include "libgnumeric.h"
-#include "gutils.h"
-#include "gnm-marshalers.h"
-#include "style-color.h"
-#include "sheet-style.h"
-#include "sheet-object-graph.h"
+#include <workbook-view.h>
+#include <workbook-control.h>
+#include <command-context.h>
+#include <application.h>
+#include <gnumeric-conf.h>
+#include <sheet.h>
+#include <sheet-view.h>
+#include <sheet-control.h>
+#include <cell.h>
+#include <expr.h>
+#include <expr-name.h>
+#include <dependent.h>
+#include <value.h>
+#include <ranges.h>
+#include <history.h>
+#include <commands.h>
+#include <libgnumeric.h>
+#include <gutils.h>
+#include <gnm-marshalers.h>
+#include <style-color.h>
+#include <sheet-style.h>
+#include <sheet-object-graph.h>
 
 #include <goffice/goffice.h>
 
 #include <gsf/gsf-doc-meta-data.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-meta-names.h>
-#include "gnm-i18n.h"
+#include <gnm-i18n.h>
 #include <string.h>
 #include <errno.h>
 
@@ -555,7 +554,7 @@ workbook_set_last_export_uri (Workbook *wb, const gchar *uri)
  * workbook_foreach_cell_in_range:
  * @pos: The position the range is relative to.
  * @cell_range: A value containing a range;
- * @flags: if TRUE only existing cells are sent to the handler.
+ * @flags: flags determining whichs cells to consider
  * @handler: (scope call): The operator to apply to each cell.
  * @closure: User data.
  *
@@ -563,14 +562,14 @@ workbook_set_last_export_uri (Workbook *wb, const gchar *uri)
  * The range bounds are calculated relative to the eval position
  * and normalized.
  * For each existing cell in the range specified, invoke the
- * callback routine.  If the only_existing flag is TRUE, then
+ * callback routine.  If the only_existing flag is %TRUE, then
  * callbacks are only invoked for existing cells.
  *
  * Note: this function does not honour the CELL_ITER_IGNORE_SUBTOTAL flag.
  *
- * Return value:
- *    non-NULL on error, or VALUE_TERMINATE if some invoked routine requested
- *    to stop (by returning non-NULL).
+ * Returns:
+ *    non-%NULL on error, or VALUE_TERMINATE if some the handler requested
+ *    to stop (by returning non-%NULL).
  */
 GnmValue *
 workbook_foreach_cell_in_range (GnmEvalPos const *pos,
@@ -1004,7 +1003,7 @@ workbook_sheet_attach_at_pos (Workbook *wb, Sheet *new_sheet, int pos)
 	pre_sheet_index_change (wb);
 
 	g_object_ref (new_sheet);
-	go_ptr_array_insert (wb->sheets, (gpointer)new_sheet, pos);
+	g_ptr_array_insert (wb->sheets, pos, (gpointer)new_sheet);
 	workbook_sheet_index_update (wb, pos);
 	g_hash_table_insert (wb->sheet_hash_private,
 			     new_sheet->name_case_insensitive,
@@ -1178,7 +1177,7 @@ workbook_sheet_move (Sheet *sheet, int direction)
 		int max_pos = MAX (old_pos, new_pos);
 
 		g_ptr_array_remove_index (wb->sheets, old_pos);
-		go_ptr_array_insert (wb->sheets, sheet, new_pos);
+		g_ptr_array_insert (wb->sheets, new_pos, sheet);
 
 		for (; max_pos >= min_pos ; max_pos--) {
 			Sheet *sheet = g_ptr_array_index (wb->sheets, max_pos);
@@ -1249,7 +1248,7 @@ workbook_sheet_get_free_name (Workbook *wb,
 /**
  * workbook_sheet_rename:
  * @wb: #Workbook in which to rename sheets
- * @sheet_indices: (element-type void): list of sheet indices (ignore -1)
+ * @sheet_indices: (element-type int): list of sheet indices (ignore -1)
  * @new_names: (element-type utf8): list of new names
  *
  * Adjusts the names of the sheets. We assume that everything is
